import OCP.StdDrivers
from typing import *
from typing import Iterable as iterable
from typing import Iterator as iterator
from numpy import float64
_Shape = Tuple[int, ...]
import OCP.TCollection
import io
import OCP.PCDM
import OCP.Storage
import OCP.CDM
import OCP.Message
import OCP.StdLDrivers
import OCP.StdObjMgt
import OCP.TDocStd
import OCP.Standard
__all__  = [
"StdDrivers",
"StdDrivers_DocumentRetrievalDriver"
]
class StdDrivers():
    @staticmethod
    def BindTypes_s(theMap : OCP.StdObjMgt.StdObjMgt_MapOfInstantiators) -> None: 
        """
        Register types.
        """
    @staticmethod
    def DefineFormat_s(theApp : OCP.TDocStd.TDocStd_Application) -> None: 
        """
        Defines format "MDTV-Standard" and registers its retrieval driver in the specified application
        """
    @staticmethod
    def Factory_s(aGUID : OCP.Standard.Standard_GUID) -> OCP.Standard.Standard_Transient: 
        """
        Depending from the ID, returns a list of storage or retrieval attribute drivers. Used for plugin
        """
    def __init__(self) -> None: ...
    pass
class StdDrivers_DocumentRetrievalDriver(OCP.StdLDrivers.StdLDrivers_DocumentRetrievalDriver, OCP.PCDM.PCDM_RetrievalDriver, OCP.PCDM.PCDM_Reader, OCP.Standard.Standard_Transient):
    """
    retrieval driver of a Part document
    """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    @staticmethod
    def DocumentVersion_s(theFileName : OCP.TCollection.TCollection_ExtendedString,theMsgDriver : OCP.Message.Message_Messenger) -> int: ...
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetFormat(self) -> OCP.TCollection.TCollection_ExtendedString: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def GetStatus(self) -> OCP.PCDM.PCDM_ReaderStatus: ...
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    @overload
    def Read(self,theFileName : OCP.TCollection.TCollection_ExtendedString,theNewDocument : OCP.CDM.CDM_Document,theApplication : OCP.CDM.CDM_Application,theFilter : OCP.PCDM.PCDM_ReaderFilter=None,theRange : OCP.Message.Message_ProgressRange=OCP.Message.Message_ProgressRange) -> None: 
        """
        Retrieve the content of a file into a new document.

        Override pure virtual method (raises exception Standard_NotImplemented)
        """
    @overload
    def Read(self,theIStream : io.BytesIO,theStorageData : OCP.Storage.Storage_Data,theDoc : OCP.CDM.CDM_Document,theApplication : OCP.CDM.CDM_Application,theFilter : OCP.PCDM.PCDM_ReaderFilter=None,theRange : OCP.Message.Message_ProgressRange=OCP.Message.Message_ProgressRange) -> None: ...
    @staticmethod
    def ReferenceCounter_s(theFileName : OCP.TCollection.TCollection_ExtendedString,theMsgDriver : OCP.Message.Message_Messenger) -> int: ...
    def SetFormat(self,aformat : OCP.TCollection.TCollection_ExtendedString) -> None: ...
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def __init__(self) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass



import OCP.FSD
from typing import *
from typing import Iterable as iterable
from typing import Iterator as iterator
from numpy import float64
_Shape = Tuple[int, ...]
import OCP.TCollection
import io
import OCP.Storage
import OCP.TColStd
import OCP.Standard
import OCP.NCollection
__all__  = [
"FSD_Base64",
"FSD_BinaryFile",
"FSD_File",
"FSD_CmpFile",
"FSD_FileHeader"
]
class FSD_Base64():
    """
    Tool for encoding/decoding base64 stream.
    """
    @staticmethod
    @overload
    def Decode_s(theDecodedData : int,theDataLen : int,theEncodedStr : str,theStrLen : int) -> int: 
        """
        Function decoding base64 string.

        Function decoding base64 string.
        """
    @staticmethod
    @overload
    def Decode_s(theStr : str,theLen : int) -> OCP.NCollection.NCollection_Buffer: ...
    @staticmethod
    @overload
    def Encode_s(theEncodedStr : str,theStrLen : int,theData : int,theDataLen : int) -> int: 
        """
        Function encoding a buffer to base64 string.

        Function encoding a buffer to base64 string.
        """
    @staticmethod
    @overload
    def Encode_s(theData : int,theDataLen : int) -> OCP.TCollection.TCollection_AsciiString: ...
    def __init__(self) -> None: ...
    pass
class FSD_BinaryFile(OCP.Storage.Storage_BaseDriver, OCP.Standard.Standard_Transient):
    def BeginReadCommentSection(self) -> OCP.Storage.Storage_Error: ...
    def BeginReadDataSection(self) -> OCP.Storage.Storage_Error: ...
    def BeginReadInfoSection(self) -> OCP.Storage.Storage_Error: ...
    def BeginReadObjectData(self) -> None: ...
    def BeginReadPersistentObjectData(self) -> None: ...
    def BeginReadRefSection(self) -> OCP.Storage.Storage_Error: ...
    def BeginReadRootSection(self) -> OCP.Storage.Storage_Error: ...
    def BeginReadTypeSection(self) -> OCP.Storage.Storage_Error: ...
    @overload
    def BeginWriteCommentSection(self) -> OCP.Storage.Storage_Error: ...
    @overload
    def BeginWriteCommentSection(self,theOStream : io.BytesIO) -> OCP.Storage.Storage_Error: ...
    def BeginWriteDataSection(self) -> OCP.Storage.Storage_Error: ...
    def BeginWriteInfoSection(self) -> OCP.Storage.Storage_Error: ...
    def BeginWriteObjectData(self) -> None: ...
    def BeginWritePersistentObjectData(self) -> None: ...
    def BeginWriteRefSection(self) -> OCP.Storage.Storage_Error: ...
    def BeginWriteRootSection(self) -> OCP.Storage.Storage_Error: ...
    def BeginWriteTypeSection(self) -> OCP.Storage.Storage_Error: ...
    def Close(self) -> OCP.Storage.Storage_Error: ...
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def Destroy(self) -> None: ...
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def EndReadCommentSection(self) -> OCP.Storage.Storage_Error: ...
    def EndReadDataSection(self) -> OCP.Storage.Storage_Error: ...
    def EndReadInfoSection(self) -> OCP.Storage.Storage_Error: ...
    def EndReadObjectData(self) -> None: ...
    def EndReadPersistentObjectData(self) -> None: ...
    def EndReadRefSection(self) -> OCP.Storage.Storage_Error: ...
    def EndReadRootSection(self) -> OCP.Storage.Storage_Error: ...
    def EndReadTypeSection(self) -> OCP.Storage.Storage_Error: ...
    @overload
    def EndWriteCommentSection(self) -> OCP.Storage.Storage_Error: ...
    @overload
    def EndWriteCommentSection(self,theOStream : io.BytesIO) -> OCP.Storage.Storage_Error: ...
    def EndWriteDataSection(self) -> OCP.Storage.Storage_Error: ...
    @overload
    def EndWriteInfoSection(self) -> OCP.Storage.Storage_Error: ...
    @overload
    def EndWriteInfoSection(self,theOStream : io.BytesIO) -> OCP.Storage.Storage_Error: ...
    def EndWriteObjectData(self) -> None: ...
    def EndWritePersistentObjectData(self) -> None: ...
    def EndWriteRefSection(self) -> OCP.Storage.Storage_Error: ...
    def EndWriteRootSection(self) -> OCP.Storage.Storage_Error: ...
    def EndWriteTypeSection(self) -> OCP.Storage.Storage_Error: ...
    def GetBoolean(self,aValue : bool) -> OCP.Storage.Storage_BaseDriver: ...
    def GetCharacter(self,aValue : str) -> OCP.Storage.Storage_BaseDriver: ...
    def GetExtCharacter(self,aValue : str) -> OCP.Storage.Storage_BaseDriver: ...
    def GetInteger(self,aValue : int) -> OCP.Storage.Storage_BaseDriver: ...
    @staticmethod
    def GetInteger_s(theIStream : io.BytesIO) -> tuple[int]: ...
    def GetReal(self,aValue : float) -> OCP.Storage.Storage_BaseDriver: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def GetReference(self,aValue : int) -> OCP.Storage.Storage_BaseDriver: ...
    @staticmethod
    def GetReference_s(theIStream : io.BytesIO) -> tuple[int]: ...
    def GetShortReal(self,aValue : float) -> OCP.Storage.Storage_BaseDriver: ...
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @staticmethod
    def InverseExtChar_s(theValue : str) -> str: 
        """
        Inverse bytes in extended character value
        """
    @staticmethod
    def InverseInt_s(theValue : int) -> int: 
        """
        Inverse bytes in integer value
        """
    @staticmethod
    def InverseReal_s(theValue : float) -> float: 
        """
        Inverse bytes in real value
        """
    @staticmethod
    def InverseShortReal_s(theValue : float) -> float: 
        """
        Inverse bytes in short real value
        """
    @staticmethod
    def InverseSize_s(theValue : int) -> int: 
        """
        Inverse bytes in size value
        """
    @staticmethod
    def InverseUint64_s(theValue : int) -> int: 
        """
        Inverse bytes in 64bit unsigned int value
        """
    def IsEnd(self) -> bool: ...
    @staticmethod
    def IsGoodFileType_s(aName : OCP.TCollection.TCollection_AsciiString) -> OCP.Storage.Storage_Error: ...
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    @staticmethod
    def MagicNumber_s() -> str: ...
    def Name(self) -> OCP.TCollection.TCollection_AsciiString: ...
    def Open(self,aName : OCP.TCollection.TCollection_AsciiString,aMode : OCP.Storage.Storage_OpenMode) -> OCP.Storage.Storage_Error: ...
    def OpenMode(self) -> OCP.Storage.Storage_OpenMode: ...
    def PutBoolean(self,aValue : bool) -> OCP.Storage.Storage_BaseDriver: ...
    def PutCharacter(self,aValue : str) -> OCP.Storage.Storage_BaseDriver: ...
    def PutExtCharacter(self,aValue : str) -> OCP.Storage.Storage_BaseDriver: ...
    def PutInteger(self,aValue : int) -> OCP.Storage.Storage_BaseDriver: ...
    @staticmethod
    def PutInteger_s(theOStream : io.BytesIO,aValue : int,theOnlyCount : bool=False) -> int: ...
    def PutReal(self,aValue : float) -> OCP.Storage.Storage_BaseDriver: ...
    def PutReference(self,aValue : int) -> OCP.Storage.Storage_BaseDriver: ...
    def PutShortReal(self,aValue : float) -> OCP.Storage.Storage_BaseDriver: ...
    def ReadComment(self,userComments : OCP.TColStd.TColStd_SequenceOfExtendedString) -> None: ...
    @staticmethod
    def ReadComment_s(theIStream : io.BytesIO,userComments : OCP.TColStd.TColStd_SequenceOfExtendedString) -> None: ...
    def ReadCompleteInfo(self,theIStream : io.BytesIO,theData : OCP.Storage.Storage_Data) -> Any: ...
    @staticmethod
    def ReadExtendedString_s(theIStream : io.BytesIO,buffer : OCP.TCollection.TCollection_ExtendedString) -> None: ...
    @staticmethod
    def ReadHeaderData_s(theIStream : io.BytesIO,theHeaderData : OCP.Storage.Storage_HeaderData) -> None: ...
    @staticmethod
    def ReadHeader_s(theIStream : io.BytesIO,theFileHeader : FSD_FileHeader) -> None: ...
    def ReadInfo(self,dbVersion : OCP.TCollection.TCollection_AsciiString,date : OCP.TCollection.TCollection_AsciiString,schemaName : OCP.TCollection.TCollection_AsciiString,schemaVersion : OCP.TCollection.TCollection_AsciiString,appName : OCP.TCollection.TCollection_ExtendedString,appVersion : OCP.TCollection.TCollection_AsciiString,objectType : OCP.TCollection.TCollection_ExtendedString,userInfo : OCP.TColStd.TColStd_SequenceOfAsciiString) -> tuple[int]: ...
    @staticmethod
    def ReadMagicNumber_s(theIStream : io.BytesIO) -> OCP.TCollection.TCollection_AsciiString: ...
    def ReadPersistentObjectHeader(self) -> tuple[int, int]: ...
    def ReadReferenceType(self) -> tuple[int, int]: ...
    @staticmethod
    def ReadReferenceType_s(theIStream : io.BytesIO) -> tuple[int, int]: ...
    def ReadRoot(self,rootName : OCP.TCollection.TCollection_AsciiString,aType : OCP.TCollection.TCollection_AsciiString) -> tuple[int]: ...
    @staticmethod
    def ReadRoot_s(theIStream : io.BytesIO,rootName : OCP.TCollection.TCollection_AsciiString,aType : OCP.TCollection.TCollection_AsciiString) -> tuple[int]: ...
    @staticmethod
    def ReadString_s(theIStream : io.BytesIO,buffer : OCP.TCollection.TCollection_AsciiString) -> None: ...
    def ReadTypeInformations(self,typeName : OCP.TCollection.TCollection_AsciiString) -> tuple[int]: ...
    @staticmethod
    def ReadTypeInformations_s(theIStream : io.BytesIO,typeName : OCP.TCollection.TCollection_AsciiString) -> tuple[int]: ...
    def RefSectionSize(self) -> int: ...
    @staticmethod
    def RefSectionSize_s(theIStream : io.BytesIO) -> int: ...
    def RootSectionSize(self) -> int: ...
    @staticmethod
    def RootSectionSize_s(theIStream : io.BytesIO) -> int: ...
    def SetRefSectionSize(self,aSize : int) -> None: ...
    def SetRootSectionSize(self,aSize : int) -> None: ...
    def SetTypeSectionSize(self,aSize : int) -> None: ...
    def SkipObject(self) -> None: ...
    def Tell(self) -> int: 
        """
        return position in the file. Return -1 upon error.
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def TypeSectionSize(self) -> int: ...
    @staticmethod
    def TypeSectionSize_s(theIStream : io.BytesIO) -> int: ...
    def WriteComment(self,userComments : OCP.TColStd.TColStd_SequenceOfExtendedString) -> None: ...
    @staticmethod
    def WriteComment_s(theOStream : io.BytesIO,theComments : OCP.TColStd.TColStd_SequenceOfExtendedString,theOnlyCount : bool=False) -> int: ...
    @staticmethod
    def WriteHeader_s(theOStream : io.BytesIO,theHeader : FSD_FileHeader,theOnlyCount : bool=False) -> int: ...
    def WriteInfo(self,nbObj : int,dbVersion : OCP.TCollection.TCollection_AsciiString,date : OCP.TCollection.TCollection_AsciiString,schemaName : OCP.TCollection.TCollection_AsciiString,schemaVersion : OCP.TCollection.TCollection_AsciiString,appName : OCP.TCollection.TCollection_ExtendedString,appVersion : OCP.TCollection.TCollection_AsciiString,objectType : OCP.TCollection.TCollection_ExtendedString,userInfo : OCP.TColStd.TColStd_SequenceOfAsciiString) -> None: ...
    @staticmethod
    def WriteInfo_s(theOStream : io.BytesIO,nbObj : int,dbVersion : OCP.TCollection.TCollection_AsciiString,date : OCP.TCollection.TCollection_AsciiString,schemaName : OCP.TCollection.TCollection_AsciiString,schemaVersion : OCP.TCollection.TCollection_AsciiString,appName : OCP.TCollection.TCollection_ExtendedString,appVersion : OCP.TCollection.TCollection_AsciiString,objectType : OCP.TCollection.TCollection_ExtendedString,userInfo : OCP.TColStd.TColStd_SequenceOfAsciiString,theOnlyCount : bool=False) -> int: ...
    def WritePersistentObjectHeader(self,aRef : int,aType : int) -> None: ...
    def WriteReferenceType(self,reference : int,typeNum : int) -> None: ...
    def WriteRoot(self,rootName : OCP.TCollection.TCollection_AsciiString,aRef : int,aType : OCP.TCollection.TCollection_AsciiString) -> None: ...
    def WriteTypeInformations(self,typeNum : int,typeName : OCP.TCollection.TCollection_AsciiString) -> None: ...
    def __init__(self) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class FSD_File(OCP.Storage.Storage_BaseDriver, OCP.Standard.Standard_Transient):
    """
    A general driver which defines as a file, the physical container for data to be stored or retrieved.A general driver which defines as a file, the physical container for data to be stored or retrieved.
    """
    def BeginReadCommentSection(self) -> OCP.Storage.Storage_Error: ...
    def BeginReadDataSection(self) -> OCP.Storage.Storage_Error: ...
    def BeginReadInfoSection(self) -> OCP.Storage.Storage_Error: ...
    def BeginReadObjectData(self) -> None: ...
    def BeginReadPersistentObjectData(self) -> None: ...
    def BeginReadRefSection(self) -> OCP.Storage.Storage_Error: ...
    def BeginReadRootSection(self) -> OCP.Storage.Storage_Error: ...
    def BeginReadTypeSection(self) -> OCP.Storage.Storage_Error: ...
    def BeginWriteCommentSection(self) -> OCP.Storage.Storage_Error: ...
    def BeginWriteDataSection(self) -> OCP.Storage.Storage_Error: ...
    def BeginWriteInfoSection(self) -> OCP.Storage.Storage_Error: ...
    def BeginWriteObjectData(self) -> None: ...
    def BeginWritePersistentObjectData(self) -> None: ...
    def BeginWriteRefSection(self) -> OCP.Storage.Storage_Error: ...
    def BeginWriteRootSection(self) -> OCP.Storage.Storage_Error: ...
    def BeginWriteTypeSection(self) -> OCP.Storage.Storage_Error: ...
    def Close(self) -> OCP.Storage.Storage_Error: 
        """
        Closes the file driven by this driver. This file was opened by the last call to the function Open. The function returns Storage_VSOk if the closure is correctly done, or any other value of the Storage_Error enumeration which specifies the problem encountered.
        """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def Destroy(self) -> None: ...
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def EndReadCommentSection(self) -> OCP.Storage.Storage_Error: ...
    def EndReadDataSection(self) -> OCP.Storage.Storage_Error: ...
    def EndReadInfoSection(self) -> OCP.Storage.Storage_Error: ...
    def EndReadObjectData(self) -> None: ...
    def EndReadPersistentObjectData(self) -> None: ...
    def EndReadRefSection(self) -> OCP.Storage.Storage_Error: ...
    def EndReadRootSection(self) -> OCP.Storage.Storage_Error: ...
    def EndReadTypeSection(self) -> OCP.Storage.Storage_Error: ...
    def EndWriteCommentSection(self) -> OCP.Storage.Storage_Error: ...
    def EndWriteDataSection(self) -> OCP.Storage.Storage_Error: ...
    def EndWriteInfoSection(self) -> OCP.Storage.Storage_Error: ...
    def EndWriteObjectData(self) -> None: ...
    def EndWritePersistentObjectData(self) -> None: ...
    def EndWriteRefSection(self) -> OCP.Storage.Storage_Error: ...
    def EndWriteRootSection(self) -> OCP.Storage.Storage_Error: ...
    def EndWriteTypeSection(self) -> OCP.Storage.Storage_Error: ...
    def GetBoolean(self,aValue : bool) -> OCP.Storage.Storage_BaseDriver: ...
    def GetCharacter(self,aValue : str) -> OCP.Storage.Storage_BaseDriver: ...
    def GetExtCharacter(self,aValue : str) -> OCP.Storage.Storage_BaseDriver: ...
    def GetInteger(self,aValue : int) -> OCP.Storage.Storage_BaseDriver: ...
    def GetReal(self,aValue : float) -> OCP.Storage.Storage_BaseDriver: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def GetReference(self,aValue : int) -> OCP.Storage.Storage_BaseDriver: ...
    def GetShortReal(self,aValue : float) -> OCP.Storage.Storage_BaseDriver: ...
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    def IsEnd(self) -> bool: ...
    @staticmethod
    def IsGoodFileType_s(aName : OCP.TCollection.TCollection_AsciiString) -> OCP.Storage.Storage_Error: ...
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    @staticmethod
    def MagicNumber_s() -> str: ...
    def Name(self) -> OCP.TCollection.TCollection_AsciiString: ...
    def Open(self,aName : OCP.TCollection.TCollection_AsciiString,aMode : OCP.Storage.Storage_OpenMode) -> OCP.Storage.Storage_Error: 
        """
        Assigns as aName the name of the file to be driven by this driver. aMode precises if the file is opened in read or write mode. The function returns Storage_VSOk if the file is opened correctly, or any other value of the Storage_Error enumeration which specifies the problem encountered.
        """
    def OpenMode(self) -> OCP.Storage.Storage_OpenMode: ...
    def PutBoolean(self,aValue : bool) -> OCP.Storage.Storage_BaseDriver: ...
    def PutCharacter(self,aValue : str) -> OCP.Storage.Storage_BaseDriver: ...
    def PutExtCharacter(self,aValue : str) -> OCP.Storage.Storage_BaseDriver: ...
    def PutInteger(self,aValue : int) -> OCP.Storage.Storage_BaseDriver: ...
    def PutReal(self,aValue : float) -> OCP.Storage.Storage_BaseDriver: ...
    def PutReference(self,aValue : int) -> OCP.Storage.Storage_BaseDriver: ...
    def PutShortReal(self,aValue : float) -> OCP.Storage.Storage_BaseDriver: ...
    def ReadComment(self,userComments : OCP.TColStd.TColStd_SequenceOfExtendedString) -> None: ...
    def ReadCompleteInfo(self,theIStream : io.BytesIO,theData : OCP.Storage.Storage_Data) -> Any: ...
    def ReadInfo(self,dbVersion : OCP.TCollection.TCollection_AsciiString,date : OCP.TCollection.TCollection_AsciiString,schemaName : OCP.TCollection.TCollection_AsciiString,schemaVersion : OCP.TCollection.TCollection_AsciiString,appName : OCP.TCollection.TCollection_ExtendedString,appVersion : OCP.TCollection.TCollection_AsciiString,objectType : OCP.TCollection.TCollection_ExtendedString,userInfo : OCP.TColStd.TColStd_SequenceOfAsciiString) -> tuple[int]: ...
    @staticmethod
    def ReadMagicNumber_s(theIStream : io.BytesIO) -> OCP.TCollection.TCollection_AsciiString: ...
    def ReadPersistentObjectHeader(self) -> tuple[int, int]: ...
    def ReadReferenceType(self) -> tuple[int, int]: ...
    def ReadRoot(self,rootName : OCP.TCollection.TCollection_AsciiString,aType : OCP.TCollection.TCollection_AsciiString) -> tuple[int]: ...
    def ReadTypeInformations(self,typeName : OCP.TCollection.TCollection_AsciiString) -> tuple[int]: ...
    def RefSectionSize(self) -> int: ...
    def RootSectionSize(self) -> int: ...
    def SetRefSectionSize(self,aSize : int) -> None: ...
    def SetRootSectionSize(self,aSize : int) -> None: ...
    def SetTypeSectionSize(self,aSize : int) -> None: ...
    def SkipObject(self) -> None: ...
    def Tell(self) -> int: 
        """
        return position in the file. Return -1 upon error.
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def TypeSectionSize(self) -> int: ...
    def WriteComment(self,userComments : OCP.TColStd.TColStd_SequenceOfExtendedString) -> None: ...
    def WriteInfo(self,nbObj : int,dbVersion : OCP.TCollection.TCollection_AsciiString,date : OCP.TCollection.TCollection_AsciiString,schemaName : OCP.TCollection.TCollection_AsciiString,schemaVersion : OCP.TCollection.TCollection_AsciiString,appName : OCP.TCollection.TCollection_ExtendedString,appVersion : OCP.TCollection.TCollection_AsciiString,objectType : OCP.TCollection.TCollection_ExtendedString,userInfo : OCP.TColStd.TColStd_SequenceOfAsciiString) -> None: ...
    def WritePersistentObjectHeader(self,aRef : int,aType : int) -> None: ...
    def WriteReferenceType(self,reference : int,typeNum : int) -> None: ...
    def WriteRoot(self,rootName : OCP.TCollection.TCollection_AsciiString,aRef : int,aType : OCP.TCollection.TCollection_AsciiString) -> None: ...
    def WriteTypeInformations(self,typeNum : int,typeName : OCP.TCollection.TCollection_AsciiString) -> None: ...
    def __init__(self) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class FSD_CmpFile(FSD_File, OCP.Storage.Storage_BaseDriver, OCP.Standard.Standard_Transient):
    def BeginReadCommentSection(self) -> OCP.Storage.Storage_Error: ...
    def BeginReadDataSection(self) -> OCP.Storage.Storage_Error: ...
    def BeginReadInfoSection(self) -> OCP.Storage.Storage_Error: ...
    def BeginReadObjectData(self) -> None: ...
    def BeginReadPersistentObjectData(self) -> None: ...
    def BeginReadRefSection(self) -> OCP.Storage.Storage_Error: ...
    def BeginReadRootSection(self) -> OCP.Storage.Storage_Error: ...
    def BeginReadTypeSection(self) -> OCP.Storage.Storage_Error: ...
    def BeginWriteCommentSection(self) -> OCP.Storage.Storage_Error: ...
    def BeginWriteDataSection(self) -> OCP.Storage.Storage_Error: ...
    def BeginWriteInfoSection(self) -> OCP.Storage.Storage_Error: ...
    def BeginWriteObjectData(self) -> None: ...
    def BeginWritePersistentObjectData(self) -> None: ...
    def BeginWriteRefSection(self) -> OCP.Storage.Storage_Error: ...
    def BeginWriteRootSection(self) -> OCP.Storage.Storage_Error: ...
    def BeginWriteTypeSection(self) -> OCP.Storage.Storage_Error: ...
    def Close(self) -> OCP.Storage.Storage_Error: 
        """
        Closes the file driven by this driver. This file was opened by the last call to the function Open. The function returns Storage_VSOk if the closure is correctly done, or any other value of the Storage_Error enumeration which specifies the problem encountered.
        """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def Destroy(self) -> None: ...
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def EndReadCommentSection(self) -> OCP.Storage.Storage_Error: ...
    def EndReadDataSection(self) -> OCP.Storage.Storage_Error: ...
    def EndReadInfoSection(self) -> OCP.Storage.Storage_Error: ...
    def EndReadObjectData(self) -> None: ...
    def EndReadPersistentObjectData(self) -> None: ...
    def EndReadRefSection(self) -> OCP.Storage.Storage_Error: ...
    def EndReadRootSection(self) -> OCP.Storage.Storage_Error: ...
    def EndReadTypeSection(self) -> OCP.Storage.Storage_Error: ...
    def EndWriteCommentSection(self) -> OCP.Storage.Storage_Error: ...
    def EndWriteDataSection(self) -> OCP.Storage.Storage_Error: ...
    def EndWriteInfoSection(self) -> OCP.Storage.Storage_Error: ...
    def EndWriteObjectData(self) -> None: ...
    def EndWritePersistentObjectData(self) -> None: ...
    def EndWriteRefSection(self) -> OCP.Storage.Storage_Error: ...
    def EndWriteRootSection(self) -> OCP.Storage.Storage_Error: ...
    def EndWriteTypeSection(self) -> OCP.Storage.Storage_Error: ...
    def GetBoolean(self,aValue : bool) -> OCP.Storage.Storage_BaseDriver: ...
    def GetCharacter(self,aValue : str) -> OCP.Storage.Storage_BaseDriver: ...
    def GetExtCharacter(self,aValue : str) -> OCP.Storage.Storage_BaseDriver: ...
    def GetInteger(self,aValue : int) -> OCP.Storage.Storage_BaseDriver: ...
    def GetReal(self,aValue : float) -> OCP.Storage.Storage_BaseDriver: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def GetReference(self,aValue : int) -> OCP.Storage.Storage_BaseDriver: ...
    def GetShortReal(self,aValue : float) -> OCP.Storage.Storage_BaseDriver: ...
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    def IsEnd(self) -> bool: ...
    @staticmethod
    def IsGoodFileType_s(aName : OCP.TCollection.TCollection_AsciiString) -> OCP.Storage.Storage_Error: ...
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    @staticmethod
    def MagicNumber_s() -> str: ...
    def Name(self) -> OCP.TCollection.TCollection_AsciiString: ...
    def Open(self,aName : OCP.TCollection.TCollection_AsciiString,aMode : OCP.Storage.Storage_OpenMode) -> OCP.Storage.Storage_Error: ...
    def OpenMode(self) -> OCP.Storage.Storage_OpenMode: ...
    def PutBoolean(self,aValue : bool) -> OCP.Storage.Storage_BaseDriver: ...
    def PutCharacter(self,aValue : str) -> OCP.Storage.Storage_BaseDriver: ...
    def PutExtCharacter(self,aValue : str) -> OCP.Storage.Storage_BaseDriver: ...
    def PutInteger(self,aValue : int) -> OCP.Storage.Storage_BaseDriver: ...
    def PutReal(self,aValue : float) -> OCP.Storage.Storage_BaseDriver: ...
    def PutReference(self,aValue : int) -> OCP.Storage.Storage_BaseDriver: ...
    def PutShortReal(self,aValue : float) -> OCP.Storage.Storage_BaseDriver: ...
    def ReadComment(self,userComments : OCP.TColStd.TColStd_SequenceOfExtendedString) -> None: ...
    def ReadCompleteInfo(self,theIStream : io.BytesIO,theData : OCP.Storage.Storage_Data) -> Any: ...
    def ReadInfo(self,dbVersion : OCP.TCollection.TCollection_AsciiString,date : OCP.TCollection.TCollection_AsciiString,schemaName : OCP.TCollection.TCollection_AsciiString,schemaVersion : OCP.TCollection.TCollection_AsciiString,appName : OCP.TCollection.TCollection_ExtendedString,appVersion : OCP.TCollection.TCollection_AsciiString,objectType : OCP.TCollection.TCollection_ExtendedString,userInfo : OCP.TColStd.TColStd_SequenceOfAsciiString) -> tuple[int]: ...
    @staticmethod
    def ReadMagicNumber_s(theIStream : io.BytesIO) -> OCP.TCollection.TCollection_AsciiString: ...
    def ReadPersistentObjectHeader(self) -> tuple[int, int]: ...
    def ReadReferenceType(self) -> tuple[int, int]: ...
    def ReadRoot(self,rootName : OCP.TCollection.TCollection_AsciiString,aType : OCP.TCollection.TCollection_AsciiString) -> tuple[int]: ...
    def ReadTypeInformations(self,typeName : OCP.TCollection.TCollection_AsciiString) -> tuple[int]: ...
    def RefSectionSize(self) -> int: ...
    def RootSectionSize(self) -> int: ...
    def SetRefSectionSize(self,aSize : int) -> None: ...
    def SetRootSectionSize(self,aSize : int) -> None: ...
    def SetTypeSectionSize(self,aSize : int) -> None: ...
    def SkipObject(self) -> None: ...
    def Tell(self) -> int: 
        """
        return position in the file. Return -1 upon error.
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def TypeSectionSize(self) -> int: ...
    def WriteComment(self,userComments : OCP.TColStd.TColStd_SequenceOfExtendedString) -> None: ...
    def WriteInfo(self,nbObj : int,dbVersion : OCP.TCollection.TCollection_AsciiString,date : OCP.TCollection.TCollection_AsciiString,schemaName : OCP.TCollection.TCollection_AsciiString,schemaVersion : OCP.TCollection.TCollection_AsciiString,appName : OCP.TCollection.TCollection_ExtendedString,appVersion : OCP.TCollection.TCollection_AsciiString,objectType : OCP.TCollection.TCollection_ExtendedString,userInfo : OCP.TColStd.TColStd_SequenceOfAsciiString) -> None: ...
    def WritePersistentObjectHeader(self,aRef : int,aType : int) -> None: ...
    def WriteReferenceType(self,reference : int,typeNum : int) -> None: ...
    def WriteRoot(self,rootName : OCP.TCollection.TCollection_AsciiString,aRef : int,aType : OCP.TCollection.TCollection_AsciiString) -> None: ...
    def WriteTypeInformations(self,typeNum : int,typeName : OCP.TCollection.TCollection_AsciiString) -> None: ...
    def __init__(self) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class FSD_FileHeader():
    def __init__(self) -> None: ...
    @property
    def bcomment(self) -> int:
        """
        :type: int
        """
    @bcomment.setter
    def bcomment(self, arg0: int) -> None:
        pass
    @property
    def bdata(self) -> int:
        """
        :type: int
        """
    @bdata.setter
    def bdata(self, arg0: int) -> None:
        pass
    @property
    def binfo(self) -> int:
        """
        :type: int
        """
    @binfo.setter
    def binfo(self, arg0: int) -> None:
        pass
    @property
    def bref(self) -> int:
        """
        :type: int
        """
    @bref.setter
    def bref(self, arg0: int) -> None:
        pass
    @property
    def broot(self) -> int:
        """
        :type: int
        """
    @broot.setter
    def broot(self, arg0: int) -> None:
        pass
    @property
    def btype(self) -> int:
        """
        :type: int
        """
    @btype.setter
    def btype(self, arg0: int) -> None:
        pass
    @property
    def ecomment(self) -> int:
        """
        :type: int
        """
    @ecomment.setter
    def ecomment(self, arg0: int) -> None:
        pass
    @property
    def edata(self) -> int:
        """
        :type: int
        """
    @edata.setter
    def edata(self, arg0: int) -> None:
        pass
    @property
    def einfo(self) -> int:
        """
        :type: int
        """
    @einfo.setter
    def einfo(self, arg0: int) -> None:
        pass
    @property
    def eref(self) -> int:
        """
        :type: int
        """
    @eref.setter
    def eref(self, arg0: int) -> None:
        pass
    @property
    def eroot(self) -> int:
        """
        :type: int
        """
    @eroot.setter
    def eroot(self, arg0: int) -> None:
        pass
    @property
    def etype(self) -> int:
        """
        :type: int
        """
    @etype.setter
    def etype(self, arg0: int) -> None:
        pass
    @property
    def testindian(self) -> int:
        """
        :type: int
        """
    @testindian.setter
    def testindian(self, arg0: int) -> None:
        pass
    pass



import OCP.GeomLib
from typing import *
from typing import Iterable as iterable
from typing import Iterator as iterator
from numpy import float64
_Shape = Tuple[int, ...]
import OCP.Geom2dAdaptor
import OCP.Geom
import OCP.gp
import OCP.TColgp
import OCP.TColStd
import OCP.AdvApprox
import OCP.math
import OCP.Geom2d
import OCP.Adaptor2d
import OCP.Adaptor3d
__all__  = [
"GeomLib",
"GeomLib_Array1OfMat",
"GeomLib_Check2dBSplineCurve",
"GeomLib_CheckBSplineCurve",
"GeomLib_CheckCurveOnSurface",
"GeomLib_DenominatorMultiplier",
"GeomLib_Interpolate",
"GeomLib_InterpolationErrors",
"GeomLib_IsPlanarSurface",
"GeomLib_LogSample",
"GeomLib_MakeCurvefromApprox",
"GeomLib_PolyFunc",
"GeomLib_Tool",
"GeomLib_DegreeSmallerThan3",
"GeomLib_InversionProblem",
"GeomLib_NoError",
"GeomLib_NotEnoughtPoints"
]
class GeomLib():
    """
    Geom Library. This package provides an implementation of functions for basic computation on geometric entity from packages Geom and Geom2d.
    """
    @staticmethod
    def AdjustExtremity_s(Curve : OCP.Geom.Geom_BoundedCurve,P1 : OCP.gp.gp_Pnt,P2 : OCP.gp.gp_Pnt,T1 : OCP.gp.gp_Vec,T2 : OCP.gp.gp_Vec) -> None: ...
    @staticmethod
    def AxeOfInertia_s(Points : OCP.TColgp.TColgp_Array1OfPnt,Axe : OCP.gp.gp_Ax2,Tol : float=1e-07) -> tuple[bool]: 
        """
        Compute axes of inertia, of some points -- -- -- <Axe>.Location() is the BaryCentre -- -- -- -- -- <Axe>.XDirection is the axe of upper inertia -- -- -- -- <Axe>.Direction is the Normal to the average plane -- -- -- IsSingular is True if points are on line -- Tol is used to determine singular cases.
        """
    @staticmethod
    def BuildCurve3d_s(Tolerance : float,CurvePtr : OCP.Adaptor3d.Adaptor3d_CurveOnSurface,FirstParameter : float,LastParameter : float,NewCurvePtr : OCP.Geom.Geom_Curve,Continuity : OCP.GeomAbs.GeomAbs_Shape=GeomAbs_Shape.GeomAbs_C1,MaxDegree : int=14,MaxSegment : int=30) -> tuple[float, float]: ...
    @staticmethod
    def CancelDenominatorDerivative_s(BSurf : OCP.Geom.Geom_BSplineSurface,UDirection : bool,VDirection : bool) -> None: 
        """
        Cancel,on the boundaries,the denominator first derivative in the directions wished by the user and set its value to 1.
        """
    @staticmethod
    def DensifyArray1OfReal_s(MinNumPoints : int,InParameters : OCP.TColStd.TColStd_Array1OfReal,OutParameters : OCP.TColStd.TColStd_HArray1OfReal) -> None: 
        """
        this makes sure that there is at least MinNumPoints in OutParameters taking into account the parameters in the InParameters array provided those are in order, that is the sequence of real in the InParameter is strictly non decreasing
        """
    @staticmethod
    def EvalMaxDistanceAlongParameter_s(Curve : OCP.Adaptor3d.Adaptor3d_Curve,AReferenceCurve : OCP.Adaptor3d.Adaptor3d_Curve,Tolerance : float,Parameters : OCP.TColStd.TColStd_Array1OfReal) -> tuple[float]: 
        """
        this will compute the maximum distance at the parameters given in the Parameters array by projecting from the Curve to the reference curve and taking the minimum distance Than the maximum will be taken on those minimas.
        """
    @staticmethod
    def EvalMaxParametricDistance_s(Curve : OCP.Adaptor3d.Adaptor3d_Curve,AReferenceCurve : OCP.Adaptor3d.Adaptor3d_Curve,Tolerance : float,Parameters : OCP.TColStd.TColStd_Array1OfReal) -> tuple[float]: 
        """
        this will compute the maximum distance at the parameters given in the Parameters array by evaluating each parameter the two curves and taking the maximum of the evaluated distance
        """
    @staticmethod
    def ExtendCurveToPoint_s(Curve : OCP.Geom.Geom_BoundedCurve,Point : OCP.gp.gp_Pnt,Cont : int,After : bool) -> None: 
        """
        Extends the bounded curve Curve to the point Point. The extension is built: - at the end of the curve if After equals true, or - at the beginning of the curve if After equals false. The extension is performed according to a degree of continuity equal to Cont, which in its turn must be equal to 1, 2 or 3. This function converts the bounded curve Curve into a BSpline curve. Warning - Nothing is done, and Curve is not modified if Cont is not equal to 1, 2 or 3. - It is recommended that the extension should not be too large with respect to the size of the bounded curve Curve: Point must not be located too far from one of the extremities of Curve.
        """
    @staticmethod
    def ExtendSurfByLength_s(Surf : OCP.Geom.Geom_BoundedSurface,Length : float,Cont : int,InU : bool,After : bool) -> None: 
        """
        Extends the bounded surface Surf along one of its boundaries. The chord length of the extension is equal to Length. The direction of the extension is given as: - the u parametric direction of Surf, if InU equals true, or - the v parametric direction of Surf, if InU equals false. In this parametric direction, the extension is built on the side of: - the last parameter of Surf, if After equals true, or - the first parameter of Surf, if After equals false. The extension is performed according to a degree of continuity equal to Cont, which in its turn must be equal to 1, 2 or 3. This function converts the bounded surface Surf into a BSpline surface. Warning - Nothing is done, and Surf is not modified if Cont is not equal to 1, 2 or 3. - It is recommended that Length, the size of the extension should not be too large with respect to the size of the bounded surface Surf. - Surf must not be a periodic BSpline surface in the parametric direction corresponding to the direction of extension.
        """
    @staticmethod
    def FuseIntervals_s(Interval1 : OCP.TColStd.TColStd_Array1OfReal,Interval2 : OCP.TColStd.TColStd_Array1OfReal,Fusion : OCP.TColStd.TColStd_SequenceOfReal,Confusion : float=1e-09,IsAdjustToFirstInterval : bool=False) -> None: 
        """
        This method fuse intervals Interval1 and Interval2 with specified Confusion
        """
    @staticmethod
    def GTransform_s(Curve : OCP.Geom2d.Geom2d_Curve,GTrsf : OCP.gp.gp_GTrsf2d) -> OCP.Geom2d.Geom2d_Curve: 
        """
        Computes the curve 3d from package Geom corresponding to the curve 3d from package Geom, transformed with the transformation <GTrsf> WARNING : this method may return a null Handle if it's impossible to compute the transformation of a curve. It's not implemented when : 1) the curve is an infinite parabola or hyperbola 2) the curve is an offsetcurve
        """
    @staticmethod
    def Inertia_s(Points : OCP.TColgp.TColgp_Array1OfPnt,Bary : OCP.gp.gp_Pnt,XDir : OCP.gp.gp_Dir,YDir : OCP.gp.gp_Dir) -> tuple[float, float, float]: 
        """
        Compute principale axes of inertia, and dispersion value of some points.
        """
    @staticmethod
    def IsBSplUClosed_s(S : OCP.Geom.Geom_BSplineSurface,U1 : float,U2 : float,Tol : float) -> bool: 
        """
        Returns true if the poles of U1 isoline and the poles of U2 isoline of surface are identical according to tolerance criterion. For rational surfaces Weights(i)*Poles(i) are checked.
        """
    @staticmethod
    def IsBSplVClosed_s(S : OCP.Geom.Geom_BSplineSurface,V1 : float,V2 : float,Tol : float) -> bool: 
        """
        Returns true if the poles of V1 isoline and the poles of V2 isoline of surface are identical according to tolerance criterion. For rational surfaces Weights(i)*Poles(i) are checked.
        """
    @staticmethod
    def IsBzUClosed_s(S : OCP.Geom.Geom_BezierSurface,U1 : float,U2 : float,Tol : float) -> bool: 
        """
        Returns true if the poles of U1 isoline and the poles of U2 isoline of surface are identical according to tolerance criterion.
        """
    @staticmethod
    def IsBzVClosed_s(S : OCP.Geom.Geom_BezierSurface,V1 : float,V2 : float,Tol : float) -> bool: 
        """
        Returns true if the poles of V1 isoline and the poles of V2 isoline of surface are identical according to tolerance criterion.
        """
    @staticmethod
    def IsClosed_s(S : OCP.Geom.Geom_Surface,Tol : float) -> tuple[bool, bool]: 
        """
        This method defines if opposite boundaries of surface coincide with given tolerance
        """
    @staticmethod
    def NormEstim_s(theSurf : OCP.Geom.Geom_Surface,theUV : OCP.gp.gp_Pnt2d,theTol : float,theNorm : OCP.gp.gp_Dir) -> int: 
        """
        Estimate surface normal at the given (U, V) point.
        """
    @staticmethod
    def RemovePointsFromArray_s(NumPoints : int,InParameters : OCP.TColStd.TColStd_Array1OfReal,OutParameters : OCP.TColStd.TColStd_HArray1OfReal) -> None: 
        """
        Warning! This assume that the InParameter is an increasing sequence of real number and it will not check for that : Unpredictable result can happen if this is not satisfied. It is the caller responsibility to check for that property.
        """
    @staticmethod
    def SameRange_s(Tolerance : float,Curve2dPtr : OCP.Geom2d.Geom2d_Curve,First : float,Last : float,RequestedFirst : float,RequestedLast : float,NewCurve2dPtr : OCP.Geom2d.Geom2d_Curve) -> None: 
        """
        Make the curve Curve2dPtr have the imposed range First to List the most economic way, that is if it can change the range without changing the nature of the curve it will try to do that. Otherwise it will produce a Bspline curve that has the required range
        """
    @staticmethod
    def To3d_s(Position : OCP.gp.gp_Ax2,Curve2d : OCP.Geom2d.Geom2d_Curve) -> OCP.Geom.Geom_Curve: 
        """
        Computes the curve 3d from package Geom corresponding to curve 2d from package Geom2d, on the plan defined with the local coordinate system Position.
        """
    def __init__(self) -> None: ...
    @staticmethod
    def buildC3dOnIsoLine_s(theC2D : OCP.Adaptor2d.Adaptor2d_Curve2d,theSurf : OCP.Adaptor3d.Adaptor3d_Surface,theFirst : float,theLast : float,theTolerance : float,theIsU : bool,theParam : float,theIsForward : bool) -> OCP.Geom.Geom_Curve: 
        """
        Builds 3D curve for a isoline. This method takes corresponding isoline from the input surface.
        """
    @staticmethod
    def isIsoLine_s(theC2D : OCP.Adaptor2d.Adaptor2d_Curve2d,theIsU : bool,theParam : float,theIsForward : bool) -> bool: 
        """
        Checks whether the 2d curve is a isoline. It can be represented by b-spline, bezier, or geometric line. This line should have natural parameterization.
        """
    pass
class GeomLib_Array1OfMat():
    """
    The class NCollection_Array1 represents unidimensional arrays of fixed size known at run time. The range of the index is user defined. An array1 can be constructed with a "C array". This functionality is useful to call methods expecting an Array1. It allows to carry the bounds inside the arrays.
    """
    def Assign(self,theOther : GeomLib_Array1OfMat) -> GeomLib_Array1OfMat: 
        """
        Copies data of theOther array to this. This array should be pre-allocated and have the same length as theOther; otherwise exception Standard_DimensionMismatch is thrown.
        """
    def ChangeFirst(self) -> OCP.gp.gp_Mat: 
        """
        Returns first element
        """
    def ChangeLast(self) -> OCP.gp.gp_Mat: 
        """
        Returns last element
        """
    def ChangeValue(self,theIndex : int) -> OCP.gp.gp_Mat: 
        """
        Variable value access
        """
    def First(self) -> OCP.gp.gp_Mat: 
        """
        Returns first element
        """
    def Init(self,theValue : OCP.gp.gp_Mat) -> None: 
        """
        Initialise the items with theValue
        """
    def IsDeletable(self) -> bool: ...
    def IsEmpty(self) -> bool: 
        """
        Return TRUE if array has zero length.
        """
    def Last(self) -> OCP.gp.gp_Mat: 
        """
        Returns last element
        """
    def Length(self) -> int: 
        """
        Length query (the same)
        """
    def Lower(self) -> int: 
        """
        Lower bound
        """
    def Move(self,theOther : GeomLib_Array1OfMat) -> GeomLib_Array1OfMat: ...
    def Resize(self,theLower : int,theUpper : int,theToCopyData : bool) -> None: 
        """
        Resizes the array to specified bounds. No re-allocation will be done if length of array does not change, but existing values will not be discarded if theToCopyData set to FALSE.
        """
    def SetValue(self,theIndex : int,theItem : OCP.gp.gp_Mat) -> None: 
        """
        Set value
        """
    def Size(self) -> int: 
        """
        Size query
        """
    def UpdateLowerBound(self,theLower : int) -> None: 
        """
        Changes the lowest bound. Do not move data
        """
    def UpdateUpperBound(self,theUpper : int) -> None: 
        """
        Changes the upper bound. Do not move data
        """
    def Upper(self) -> int: 
        """
        Upper bound
        """
    def Value(self,theIndex : int) -> OCP.gp.gp_Mat: 
        """
        Constant value access
        """
    def __bool__(self) -> bool: ...
    def __call__(self,theIndex : int) -> OCP.gp.gp_Mat: ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,theLower : int,theUpper : int) -> None: ...
    @overload
    def __init__(self,theAlloc : Any,theLower : int,theUpper : int) -> None: ...
    @overload
    def __init__(self,theOther : GeomLib_Array1OfMat) -> None: ...
    def __iter__(self) -> Iterator[OCP.gp.gp_Mat]: ...
    def __len__(self) -> int: ...
    pass
class GeomLib_Check2dBSplineCurve():
    """
    Checks for the end tangents : whether or not those are reversed
    """
    def FixTangent(self,FirstFlag : bool,LastFlag : bool) -> None: ...
    def FixedTangent(self,FirstFlag : bool,LastFlag : bool) -> OCP.Geom2d.Geom2d_BSplineCurve: 
        """
        modifies the curve by fixing the first or the last tangencies
        """
    def IsDone(self) -> bool: ...
    def NeedTangentFix(self) -> tuple[bool, bool]: ...
    def __init__(self,Curve : OCP.Geom2d.Geom2d_BSplineCurve,Tolerance : float,AngularTolerance : float) -> None: ...
    pass
class GeomLib_CheckBSplineCurve():
    """
    Checks for the end tangents : whether or not those are reversed regarding the third or n-3rd control
    """
    def FixTangent(self,FirstFlag : bool,LastFlag : bool) -> None: ...
    def FixedTangent(self,FirstFlag : bool,LastFlag : bool) -> OCP.Geom.Geom_BSplineCurve: 
        """
        modifies the curve by fixing the first or the last tangencies
        """
    def IsDone(self) -> bool: ...
    def NeedTangentFix(self) -> tuple[bool, bool]: ...
    def __init__(self,Curve : OCP.Geom.Geom_BSplineCurve,Tolerance : float,AngularTolerance : float) -> None: ...
    pass
class GeomLib_CheckCurveOnSurface():
    """
    Computes the max distance between 3D-curve and 2D-curve in some surface.
    """
    def ErrorStatus(self) -> int: 
        """
        Returns error status The possible values are: 0 - OK; 1 - null curve or surface or 2d curve; 2 - invalid parametric range; 3 - error in calculations.
        """
    @overload
    def Init(self,theCurve : OCP.Adaptor3d.Adaptor3d_Curve,theTolRange : float=1e-09) -> None: 
        """
        Sets the data for the algorithm

        Initializes all members by default values
        """
    @overload
    def Init(self) -> None: ...
    def IsDone(self) -> bool: 
        """
        Returns true if the max distance has been found
        """
    def IsParallel(self) -> bool: 
        """
        Returns true if parallel flag is set
        """
    def MaxDistance(self) -> float: 
        """
        Returns max distance
        """
    def MaxParameter(self) -> float: 
        """
        Returns parameter in which the distance is maximal
        """
    def Perform(self,theCurveOnSurface : OCP.Adaptor3d.Adaptor3d_CurveOnSurface) -> None: 
        """
        Computes the max distance for the 3d curve <myCurve> and 2d curve <theCurveOnSurface> If isMultiThread == Standard_True then computation will be performed in parallel.
        """
    def SetParallel(self,theIsParallel : bool) -> None: 
        """
        Sets parallel flag
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,theCurve : OCP.Adaptor3d.Adaptor3d_Curve,theTolRange : float=1e-09) -> None: ...
    pass
class GeomLib_DenominatorMultiplier():
    """
    this defines an evaluator for a function of 2 variables that will be used by CancelDenominatorDerivative in one direction.
    """
    def Value(self,UParameter : float,VParameter : float) -> float: 
        """
        Returns the value of a(UParameter,VParameter)=
        """
    def __init__(self,Surface : OCP.Geom.Geom_BSplineSurface,KnotVector : OCP.TColStd.TColStd_Array1OfReal) -> None: ...
    pass
class GeomLib_Interpolate():
    """
    this class is used to construct a BSpline curve by interpolation of points at given parameters The continuity of the curve is degree - 1 and the method used when boundary condition are not given is to use odd degrees and null the derivatives on both sides from degree -1 down to (degree+1) / 2 When even degree is given the returned curve is of degree - 1 so that the degree of the curve is odd
    """
    def Curve(self) -> OCP.Geom.Geom_BSplineCurve: 
        """
        returns the interpolated curve of the requested degree
        """
    def Error(self) -> GeomLib_InterpolationErrors: 
        """
        returns the error type if any

        returns the error type if any
        """
    def IsDone(self) -> bool: 
        """
        returns if everything went OK

        returns if everything went OK
        """
    def __init__(self,Degree : int,NumPoints : int,Points : OCP.TColgp.TColgp_Array1OfPnt,Parameters : OCP.TColStd.TColStd_Array1OfReal) -> None: ...
    pass
class GeomLib_InterpolationErrors():
    """
    in case the interpolation errors out, this tells what happened

    Members:

      GeomLib_NoError

      GeomLib_NotEnoughtPoints

      GeomLib_DegreeSmallerThan3

      GeomLib_InversionProblem
    """
    def __eq__(self,other : object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __init__(self,value : int) -> None: ...
    def __int__(self) -> int: ...
    def __ne__(self,other : object) -> bool: ...
    def __repr__(self) -> str: ...
    def __setstate__(self,state : int) -> None: ...
    def __str__(self) -> str: ...
    @property
    def name(self) -> None:
        """
        :type: None
        """
    @property
    def value(self) -> int:
        """
        :type: int
        """
    GeomLib_DegreeSmallerThan3: OCP.GeomLib.GeomLib_InterpolationErrors # value = <GeomLib_InterpolationErrors.GeomLib_DegreeSmallerThan3: 2>
    GeomLib_InversionProblem: OCP.GeomLib.GeomLib_InterpolationErrors # value = <GeomLib_InterpolationErrors.GeomLib_InversionProblem: 3>
    GeomLib_NoError: OCP.GeomLib.GeomLib_InterpolationErrors # value = <GeomLib_InterpolationErrors.GeomLib_NoError: 0>
    GeomLib_NotEnoughtPoints: OCP.GeomLib.GeomLib_InterpolationErrors # value = <GeomLib_InterpolationErrors.GeomLib_NotEnoughtPoints: 1>
    __entries: dict # value = {'GeomLib_NoError': (<GeomLib_InterpolationErrors.GeomLib_NoError: 0>, None), 'GeomLib_NotEnoughtPoints': (<GeomLib_InterpolationErrors.GeomLib_NotEnoughtPoints: 1>, None), 'GeomLib_DegreeSmallerThan3': (<GeomLib_InterpolationErrors.GeomLib_DegreeSmallerThan3: 2>, None), 'GeomLib_InversionProblem': (<GeomLib_InterpolationErrors.GeomLib_InversionProblem: 3>, None)}
    __members__: dict # value = {'GeomLib_NoError': <GeomLib_InterpolationErrors.GeomLib_NoError: 0>, 'GeomLib_NotEnoughtPoints': <GeomLib_InterpolationErrors.GeomLib_NotEnoughtPoints: 1>, 'GeomLib_DegreeSmallerThan3': <GeomLib_InterpolationErrors.GeomLib_DegreeSmallerThan3: 2>, 'GeomLib_InversionProblem': <GeomLib_InterpolationErrors.GeomLib_InversionProblem: 3>}
    pass
class GeomLib_IsPlanarSurface():
    """
    Find if a surface is a planar surface.
    """
    def IsPlanar(self) -> bool: 
        """
        Return if the Surface is a plan
        """
    def Plan(self) -> OCP.gp.gp_Pln: 
        """
        Return the plan definition
        """
    def __init__(self,S : OCP.Geom.Geom_Surface,Tol : float=1e-07) -> None: ...
    pass
class GeomLib_LogSample(OCP.math.math_FunctionSample):
    def Bounds(self) -> tuple[float, float]: 
        """
        Returns the bounds of parameters.
        """
    def GetParameter(self,Index : int) -> float: 
        """
        Returns the value of parameter of the point of range Index : A + ((Index-1)/(NbPoints-1))*B. An exception is raised if Index<=0 or Index>NbPoints.
        """
    def NbPoints(self) -> int: 
        """
        Returns the number of sample points.
        """
    def __init__(self,A : float,B : float,N : int) -> None: ...
    pass
class GeomLib_MakeCurvefromApprox():
    """
    this class is used to construct the BSpline curve from an Approximation ( ApproxAFunction from AdvApprox).
    """
    @overload
    def Curve(self,Index3d : int) -> OCP.Geom.Geom_BSplineCurve: 
        """
        returns a polynomial curve whose poles correspond to the Index3D 3D space if Index3D not in the Range [1,Nb3dSpaces] if the Approx is not Done

        returns a rational curve whose poles correspond to the index3D of the 3D space and whose weights correspond to the index1d 1D space. if Index1D not in the Range [1,Nb1dSpaces] if Index3D not in the Range [1,Nb3dSpaces] if the Approx is not Done
        """
    @overload
    def Curve(self,Index1D : int,Index3D : int) -> OCP.Geom.Geom_BSplineCurve: ...
    @overload
    def Curve2d(self,Index2d : int) -> OCP.Geom2d.Geom2d_BSplineCurve: 
        """
        returns a polynomial curve whose poles correspond to the Index2d 2D space if Index2d not in the Range [1,Nb2dSpaces] if the Approx is not Done

        returns a rational curve whose poles correspond to the index2d of the 2D space and whose weights correspond to one dimensional space of index 1d if Index1d not in the Range [1,Nb1dSpaces] if Index2d not in the Range [1,Nb2dSpaces] if the Approx is not Done
        """
    @overload
    def Curve2d(self,Index1d : int,Index2d : int) -> OCP.Geom2d.Geom2d_BSplineCurve: ...
    def Curve2dFromTwo1d(self,Index1d : int,Index2d : int) -> OCP.Geom2d.Geom2d_BSplineCurve: 
        """
        returns a 2D curve building it from the 1D curve in x at Index1d and y at Index2d amongst the 1D curves if Index1d not in the Range [1,Nb1dSpaces] if Index2d not in the Range [1,Nb1dSpaces] if the Approx is not Done
        """
    def IsDone(self) -> bool: ...
    def Nb1DSpaces(self) -> int: 
        """
        returns the number of 1D spaces of the Approx
        """
    def Nb2DSpaces(self) -> int: 
        """
        returns the number of 3D spaces of the Approx
        """
    def Nb3DSpaces(self) -> int: 
        """
        returns the number of 3D spaces of the Approx
        """
    def __init__(self,Approx : OCP.AdvApprox.AdvApprox_ApproxAFunction) -> None: ...
    pass
class GeomLib_PolyFunc(OCP.math.math_FunctionWithDerivative, OCP.math.math_Function):
    """
    Polynomial Function
    """
    def Derivative(self,X : float,D : float) -> bool: 
        """
        computes the derivative <D> of the function for the variable <X>. Returns True if the calculation were successfully done, False otherwise.
        """
    def GetStateNumber(self) -> int: 
        """
        returns the state of the function corresponding to the latest call of any methods associated with the function. This function is called by each of the algorithms described later which defined the function Integer Algorithm::StateNumber(). The algorithm has the responsibility to call this function when it has found a solution (i.e. a root or a minimum) and has to maintain the association between the solution found and this StateNumber. Byu default, this method returns 0 (which means for the algorithm: no state has been saved). It is the responsibility of the programmer to decide if he needs to save the current state of the function and to return an Integer that allows retrieval of the state.
        """
    def Value(self,X : float,F : float) -> bool: 
        """
        computes the value <F>of the function for the variable <X>. Returns True if the calculation were successfully done, False otherwise.
        """
    def Values(self,X : float,F : float,D : float) -> bool: 
        """
        computes the value <F> and the derivative <D> of the function for the variable <X>. Returns True if the calculation were successfully done, False otherwise.
        """
    def __init__(self,Coeffs : Any) -> None: ...
    pass
class GeomLib_Tool():
    """
    Provides various methods with Geom2d and Geom curves and surfaces. The methods of this class compute the parameter(s) of a given point on a curve or a surface. To get the valid result the point must be located rather close to the curve (surface) or at least to allow getting unambiguous result (do not put point at center of circle...), but choice of "trust" distance between curve/surface and point is responsibility of user (parameter MaxDist). Return FALSE if the point is beyond the MaxDist limit or if computation fails.
    """
    @staticmethod
    @overload
    def ComputeDeviation_s(theCurve : OCP.Geom2dAdaptor.Geom2dAdaptor_Curve,theFPar : float,theLPar : float,theStartParameter : float,theNbIters : int=100,thePrmOnCurve : float=None,thePtOnCurve : OCP.gp.gp_Pnt2d=None,theVecCurvLine : OCP.gp.gp_Vec2d=None,theLine : OCP.gp.gp_Lin2d=None) -> float: 
        """
        Computes parameter in theCurve (*thePrmOnCurve) where maximal deviation between theCurve and the linear segment joining its points with the parameters theFPar and theLPar is obtained. Returns the (positive) value of deviation. Returns negative value if the deviation cannot be computed. The returned parameter (in case of successful) will always be in the range [theFPar, theLPar]. Iterative method is used for computation. So, theStartParameter is needed to be set. Recommend value of theStartParameter can be found with the overloaded method. Additionally, following values can be returned (optionally):

        Computes parameter in theCurve (*thePrmOnCurve) where maximal deviation between theCurve and the linear segment joining its points with the parameters theFPar and theLPar is obtained. Returns the (positive) value of deviation. Returns negative value if the deviation cannot be computed. The returned parameter (in case of successful) will always be in the range [theFPar, theLPar]. theNbSubIntervals defines discretization of the given interval [theFPar, theLPar] to provide better search condition. This value should be chosen taking into account complexity of the curve in considered interval. E.g. if there are many oscillations of the curve in the interval then theNbSubIntervals mus be great number. However, the greater value of theNbSubIntervals the slower the algorithm will compute. theNbIters sets number of iterations. ATTENTION!!! This algorithm cannot compute deviation precisely (so, there is no point in setting big value of theNbIters). But it can give some start point for the overloaded method.
        """
    @staticmethod
    @overload
    def ComputeDeviation_s(theCurve : OCP.Geom2dAdaptor.Geom2dAdaptor_Curve,theFPar : float,theLPar : float,theNbSubIntervals : int,theNbIters : int=10,thePrmOnCurve : float=None) -> float: ...
    @staticmethod
    @overload
    def Parameter_s(Curve : OCP.Geom.Geom_Curve,Point : OCP.gp.gp_Pnt,MaxDist : float,U : float) -> bool: 
        """
        Extracts the parameter of a 3D point lying on a 3D curve or at a distance less than the MaxDist value.

        Extracts the parameter of a 2D point lying on a 2D curve or at a distance less than the MaxDist value.
        """
    @staticmethod
    @overload
    def Parameter_s(Curve : OCP.Geom2d.Geom2d_Curve,Point : OCP.gp.gp_Pnt2d,MaxDist : float,U : float) -> bool: ...
    @staticmethod
    def Parameters_s(Surface : OCP.Geom.Geom_Surface,Point : OCP.gp.gp_Pnt,MaxDist : float,U : float,V : float) -> bool: 
        """
        Extracts the parameter of a 3D point lying on a surface or at a distance less than the MaxDist value.
        """
    def __init__(self) -> None: ...
    pass
GeomLib_DegreeSmallerThan3: OCP.GeomLib.GeomLib_InterpolationErrors # value = <GeomLib_InterpolationErrors.GeomLib_DegreeSmallerThan3: 2>
GeomLib_InversionProblem: OCP.GeomLib.GeomLib_InterpolationErrors # value = <GeomLib_InterpolationErrors.GeomLib_InversionProblem: 3>
GeomLib_NoError: OCP.GeomLib.GeomLib_InterpolationErrors # value = <GeomLib_InterpolationErrors.GeomLib_NoError: 0>
GeomLib_NotEnoughtPoints: OCP.GeomLib.GeomLib_InterpolationErrors # value = <GeomLib_InterpolationErrors.GeomLib_NotEnoughtPoints: 1>



import OCP.GeomConvert
from typing import *
from typing import Iterable as iterable
from typing import Iterator as iterator
from numpy import float64
_Shape = Tuple[int, ...]
import io
import OCP.gp
import OCP.Geom
import OCP.TColgp
import OCP.TColStd
import OCP.math
import OCP.GeomAbs
import OCP.Geom2d
import OCP.TColGeom
import OCP.Adaptor3d
__all__  = [
"GeomConvert",
"GeomConvert_ApproxCurve",
"GeomConvert_ApproxSurface",
"GeomConvert_BSplineCurveKnotSplitting",
"GeomConvert_BSplineCurveToBezierCurve",
"GeomConvert_BSplineSurfaceKnotSplitting",
"GeomConvert_BSplineSurfaceToBezierSurface",
"GeomConvert_CompBezierSurfacesToBSplineSurface",
"GeomConvert_CompCurveToBSplineCurve",
"GeomConvert_ConvType",
"GeomConvert_CurveToAnaCurve",
"GeomConvert_FuncConeLSDist",
"GeomConvert_FuncCylinderLSDist",
"GeomConvert_FuncSphereLSDist",
"GeomConvert_SurfToAnaSurf",
"GeomConvert_Units",
"GeomConvert_MinGap",
"GeomConvert_Simplest",
"GeomConvert_Target"
]
class GeomConvert():
    """
    The GeomConvert package provides some global functions as follows - converting classical Geom curves into BSpline curves, - segmenting BSpline curves, particularly at knots values: this function may be used in conjunction with the GeomConvert_BSplineCurveKnotSplitting class to segment a BSpline curve into arcs which comply with required continuity levels, - converting classical Geom surfaces into BSpline surfaces, and - segmenting BSpline surfaces, particularly at knots values: this function may be used in conjunction with the GeomConvert_BSplineSurfaceKnotSplitting class to segment a BSpline surface into patches which comply with required continuity levels. All geometric entities used in this package are bounded.
    """
    @staticmethod
    @overload
    def C0BSplineToArrayOfC1BSplineCurve_s(BS : OCP.Geom.Geom_BSplineCurve,tabBS : OCP.TColGeom.TColGeom_HArray1OfBSplineCurve,tolerance : float) -> None: 
        """
        This Method reduces as far as it is possible the multiplicities of the knots of the BSpline BS.(keeping the geometry). It returns an array of BSpline C1. tolerance is a geometrical tolerance.

        This Method reduces as far as it is possible the multiplicities of the knots of the BSpline BS.(keeping the geometry). It returns an array of BSpline C1. tolerance is a geometrical tolerance : it allows for the maximum deformation The Angular tolerance is in radians and measures the angle of the tangents on the left and on the right to decide if the curve is C1 or not at a given point
        """
    @staticmethod
    @overload
    def C0BSplineToArrayOfC1BSplineCurve_s(BS : OCP.Geom.Geom_BSplineCurve,tabBS : OCP.TColGeom.TColGeom_HArray1OfBSplineCurve,AngularTolerance : float,tolerance : float) -> None: ...
    @staticmethod
    def C0BSplineToC1BSplineCurve_s(BS : OCP.Geom.Geom_BSplineCurve,tolerance : float,AngularTolerance : float=1e-07) -> None: 
        """
        This Method reduces as far as it is possible the multiplicities of the knots of the BSpline BS.(keeping the geometry). It returns a new BSpline which could still be C0. tolerance is a geometrical tolerance. The Angular toleranceis in radians and measures the angle of the tangents on the left and on the right to decide if the curve is G1 or not at a given point
        """
    @staticmethod
    @overload
    def ConcatC1_s(ArrayOfCurves : OCP.TColGeom.TColGeom_Array1OfBSplineCurve,ArrayOfToler : OCP.TColStd.TColStd_Array1OfReal,ArrayOfIndices : OCP.TColStd.TColStd_HArray1OfInteger,ArrayOfConcatenated : OCP.TColGeom.TColGeom_HArray1OfBSplineCurve,ClosedTolerance : float) -> tuple[bool]: 
        """
        This Method concatenates C1 the ArrayOfCurves as far as it is possible. ArrayOfCurves[0..N-1] ArrayOfToler contains the biggest tolerance of the two points shared by two consecutives curves. Its dimension: [0..N-2] ClosedFlag indicates if the ArrayOfCurves is closed. In this case ClosedTolerance contains the biggest tolerance of the two points which are at the closure. Otherwise its value is 0.0 ClosedFlag becomes False on the output if it is impossible to build closed curve.

        This Method concatenates C1 the ArrayOfCurves as far as it is possible. ArrayOfCurves[0..N-1] ArrayOfToler contains the biggest tolerance of the two points shared by two consecutives curves. Its dimension: [0..N-2] ClosedFlag indicates if the ArrayOfCurves is closed. In this case ClosedTolerance contains the biggest tolerance of the two points which are at the closure. Otherwise its value is 0.0 ClosedFlag becomes False on the output if it is impossible to build closed curve.
        """
    @staticmethod
    @overload
    def ConcatC1_s(ArrayOfCurves : OCP.TColGeom.TColGeom_Array1OfBSplineCurve,ArrayOfToler : OCP.TColStd.TColStd_Array1OfReal,ArrayOfIndices : OCP.TColStd.TColStd_HArray1OfInteger,ArrayOfConcatenated : OCP.TColGeom.TColGeom_HArray1OfBSplineCurve,ClosedTolerance : float,AngularTolerance : float) -> tuple[bool]: ...
    @staticmethod
    def ConcatG1_s(ArrayOfCurves : OCP.TColGeom.TColGeom_Array1OfBSplineCurve,ArrayOfToler : OCP.TColStd.TColStd_Array1OfReal,ArrayOfConcatenated : OCP.TColGeom.TColGeom_HArray1OfBSplineCurve,ClosedTolerance : float) -> tuple[bool]: 
        """
        This Method concatenates G1 the ArrayOfCurves as far as it is possible. ArrayOfCurves[0..N-1] ArrayOfToler contains the biggest tolerance of the two points shared by two consecutives curves. Its dimension: [0..N-2] ClosedFlag indicates if the ArrayOfCurves is closed. In this case ClosedTolerance contains the biggest tolerance of the two points which are at the closure. Otherwise its value is 0.0 ClosedFlag becomes False on the output if it is impossible to build closed curve.
        """
    @staticmethod
    def CurveToBSplineCurve_s(C : OCP.Geom.Geom_Curve,Parameterisation : OCP.Convert.Convert_ParameterisationType=Convert_ParameterisationType.Convert_TgtThetaOver2) -> OCP.Geom.Geom_BSplineCurve: 
        """
        This function converts a non infinite curve from Geom into a B-spline curve. C must be an ellipse or a circle or a trimmed conic or a trimmed line or a Bezier curve or a trimmed Bezier curve or a BSpline curve or a trimmed BSpline curve or an OffsetCurve. The returned B-spline is not periodic except if C is a Circle or an Ellipse. If the Parameterisation is QuasiAngular than the returned curve is NOT periodic in case a periodic Geom_Circle or Geom_Ellipse. For TgtThetaOver2_1 and TgtThetaOver2_2 the method raises an exception in case of a periodic Geom_Circle or a Geom_Ellipse ParameterisationType applies only if the curve is a Circle or an ellipse : TgtThetaOver2, -- TgtThetaOver2_1, -- TgtThetaOver2_2, -- TgtThetaOver2_3, -- TgtThetaOver2_4,
        """
    @staticmethod
    @overload
    def SplitBSplineCurve_s(C : OCP.Geom.Geom_BSplineCurve,FromK1 : int,ToK2 : int,SameOrientation : bool=True) -> OCP.Geom.Geom_BSplineCurve: 
        """
        Convert a curve from Geom by an approximation method

        This function computes the segment of B-spline curve between the parametric values FromU1, ToU2. If C is periodic the arc has the same orientation as C if SameOrientation = True. If C is not periodic SameOrientation is not used for the computation and C is oriented fromU1 toU2. If U1 and U2 and two parametric values we consider that U1 = U2 if Abs (U1 - U2) <= ParametricTolerance and ParametricTolerance must be greater or equal to Resolution from package gp.
        """
    @staticmethod
    @overload
    def SplitBSplineCurve_s(C : OCP.Geom.Geom_BSplineCurve,FromU1 : float,ToU2 : float,ParametricTolerance : float,SameOrientation : bool=True) -> OCP.Geom.Geom_BSplineCurve: ...
    @staticmethod
    @overload
    def SplitBSplineSurface_s(S : OCP.Geom.Geom_BSplineSurface,FromUK1 : int,ToUK2 : int,FromVK1 : int,ToVK2 : int,SameUOrientation : bool=True,SameVOrientation : bool=True) -> OCP.Geom.Geom_BSplineSurface: 
        """
        Computes the B-spline surface patche between the knots values FromUK1, ToUK2, FromVK1, ToVK2. If S is periodic in one direction the patche has the same orientation as S in this direction if the flag is true in this direction (SameUOrientation, SameVOrientation). If S is not periodic SameUOrientation and SameVOrientation are not used for the computation and S is oriented FromUK1 ToUK2 and FromVK1 ToVK2. Raised if FromUK1 = ToUK2 or FromVK1 = ToVK2 FromUK1 or ToUK2 are out of the bounds [FirstUKnotIndex, LastUKnotIndex] FromVK1 or ToVK2 are out of the bounds [FirstVKnotIndex, LastVKnotIndex]

        This method splits a B-spline surface patche between the knots values FromK1, ToK2 in one direction. If USplit = True then the splitting direction is the U parametric direction else it is the V parametric direction. If S is periodic in the considered direction the patche has the same orientation as S in this direction if SameOrientation is True If S is not periodic in this direction SameOrientation is not used for the computation and S is oriented FromK1 ToK2. Raised if FromK1 = ToK2 or if FromK1 or ToK2 are out of the bounds [FirstUKnotIndex, LastUKnotIndex] in the considered parametric direction.

        This method computes the B-spline surface patche between the parametric values FromU1, ToU2, FromV1, ToV2. If S is periodic in one direction the patche has the same orientation as S in this direction if the flag is True in this direction (SameUOrientation, SameVOrientation). If S is not periodic SameUOrientation and SameVOrientation are not used for the computation and S is oriented FromU1 ToU2 and FromV1 ToV2. If U1 and U2 and two parametric values we consider that U1 = U2 if Abs (U1 - U2) <= ParametricTolerance and ParametricTolerance must be greater or equal to Resolution from package gp.

        This method splits the B-spline surface S in one direction between the parametric values FromParam1, ToParam2. If USplit = True then the Splitting direction is the U parametric direction else it is the V parametric direction. If S is periodic in the considered direction the patche has the same orientation as S in this direction if SameOrientation is true. If S is not periodic in the considered direction SameOrientation is not used for the computation and S is oriented FromParam1 ToParam2. If U1 and U2 and two parametric values we consider that U1 = U2 if Abs (U1 - U2) <= ParametricTolerance and ParametricTolerance must be greater or equal to Resolution from package gp.
        """
    @staticmethod
    @overload
    def SplitBSplineSurface_s(S : OCP.Geom.Geom_BSplineSurface,FromK1 : int,ToK2 : int,USplit : bool,SameOrientation : bool=True) -> OCP.Geom.Geom_BSplineSurface: ...
    @staticmethod
    @overload
    def SplitBSplineSurface_s(S : OCP.Geom.Geom_BSplineSurface,FromU1 : float,ToU2 : float,FromV1 : float,ToV2 : float,ParametricTolerance : float,SameUOrientation : bool=True,SameVOrientation : bool=True) -> OCP.Geom.Geom_BSplineSurface: ...
    @staticmethod
    @overload
    def SplitBSplineSurface_s(S : OCP.Geom.Geom_BSplineSurface,FromParam1 : float,ToParam2 : float,USplit : bool,ParametricTolerance : float,SameOrientation : bool=True) -> OCP.Geom.Geom_BSplineSurface: ...
    @staticmethod
    def SurfaceToBSplineSurface_s(S : OCP.Geom.Geom_Surface) -> OCP.Geom.Geom_BSplineSurface: 
        """
        This algorithm converts a non infinite surface from Geom into a B-spline surface. S must be a trimmed plane or a trimmed cylinder or a trimmed cone or a trimmed sphere or a trimmed torus or a sphere or a torus or a Bezier surface of a trimmed Bezier surface or a trimmed swept surface with a corresponding basis curve which can be turned into a B-spline curve (see the method CurveToBSplineCurve). Raises DomainError if the type of the surface is not previously defined.
        """
    def __init__(self) -> None: ...
    pass
class GeomConvert_ApproxCurve():
    """
    A framework to convert a 3D curve to a 3D BSpline. This is done by approximation to a BSpline curve within a given tolerance.
    """
    def Curve(self) -> OCP.Geom.Geom_BSplineCurve: 
        """
        Returns the BSpline curve resulting from the approximation algorithm.
        """
    def Dump(self,o : io.BytesIO) -> None: 
        """
        Print on the stream o information about the object
        """
    def HasResult(self) -> bool: 
        """
        Returns Standard_True if the approximation did come out with a result that is not NECESSARELY within the required tolerance
        """
    def IsDone(self) -> bool: 
        """
        returns Standard_True if the approximation has been done within required tolerance
        """
    def MaxError(self) -> float: 
        """
        Returns the greatest distance between a point on the source conic and the BSpline curve resulting from the approximation. (>0 when an approximation has been done, 0 if no approximation)
        """
    @overload
    def __init__(self,Curve : OCP.Geom.Geom_Curve,Tol3d : float,Order : OCP.GeomAbs.GeomAbs_Shape,MaxSegments : int,MaxDegree : int) -> None: ...
    @overload
    def __init__(self,Curve : OCP.Adaptor3d.Adaptor3d_Curve,Tol3d : float,Order : OCP.GeomAbs.GeomAbs_Shape,MaxSegments : int,MaxDegree : int) -> None: ...
    pass
class GeomConvert_ApproxSurface():
    """
    A framework to convert a surface to a BSpline surface. This is done by approximation to a BSpline surface within a given tolerance.
    """
    def Dump(self,o : io.BytesIO) -> None: 
        """
        Prints on the stream o information on the current state of the object.
        """
    def HasResult(self) -> bool: 
        """
        Returns true if the approximation did come out with a result that is not NECESSARILY within the required tolerance or a result that is not recognized with the wished continuities.
        """
    def IsDone(self) -> bool: 
        """
        Returns Standard_True if the approximation has be done
        """
    def MaxError(self) -> float: 
        """
        Returns the greatest distance between a point on the source conic surface and the BSpline surface resulting from the approximation (>0 when an approximation has been done, 0 if no approximation )
        """
    def Surface(self) -> OCP.Geom.Geom_BSplineSurface: 
        """
        Returns the BSpline surface resulting from the approximation algorithm.
        """
    @overload
    def __init__(self,Surf : OCP.Geom.Geom_Surface,Tol3d : float,UContinuity : OCP.GeomAbs.GeomAbs_Shape,VContinuity : OCP.GeomAbs.GeomAbs_Shape,MaxDegU : int,MaxDegV : int,MaxSegments : int,PrecisCode : int) -> None: ...
    @overload
    def __init__(self,Surf : OCP.Adaptor3d.Adaptor3d_Surface,Tol3d : float,UContinuity : OCP.GeomAbs.GeomAbs_Shape,VContinuity : OCP.GeomAbs.GeomAbs_Shape,MaxDegU : int,MaxDegV : int,MaxSegments : int,PrecisCode : int) -> None: ...
    pass
class GeomConvert_BSplineCurveKnotSplitting():
    """
    An algorithm to determine points at which a BSpline curve should be split in order to obtain arcs of the same continuity. If you require curves with a minimum continuity for your computation, it is useful to know the points between which an arc has a continuity of a given order. The continuity order is given at the construction time. For a BSpline curve, the discontinuities are localized at the knot values. Between two knot values the BSpline is infinitely and continuously differentiable. At a given knot, the continuity is equal to: Degree - Mult, where Degree is the degree of the BSpline curve and Mult is the multiplicity of the knot. It is possible to compute the arcs which correspond to this splitting using the global function SplitBSplineCurve provided by the package GeomConvert. A BSplineCurveKnotSplitting object provides a framework for: - defining the curve to be analyzed and the required degree of continuity, - implementing the computation algorithm, and - consulting the results.
    """
    def NbSplits(self) -> int: 
        """
        Returns the number of points at which the analyzed BSpline curve should be split, in order to obtain arcs with the continuity required by this framework. All these points correspond to knot values. Note that the first and last points of the curve, which bound the first and last arcs, are counted among these splitting points.
        """
    def SplitValue(self,Index : int) -> int: 
        """
        Returns the split knot of index Index to the split knots table computed in this framework. The returned value is an index in the knots table of the BSpline curve analyzed by this algorithm. Notes: - If Index is equal to 1, the corresponding knot gives the first point of the curve. - If Index is equal to the number of split knots computed in this framework, the corresponding point is the last point of the curve. Exceptions Standard_RangeError if Index is less than 1 or greater than the number of split knots computed in this framework.
        """
    def Splitting(self,SplitValues : OCP.TColStd.TColStd_Array1OfInteger) -> None: 
        """
        Loads the SplitValues table with the split knots values computed in this framework. Each value in the table is an index in the knots table of the BSpline curve analyzed by this algorithm. The values in SplitValues are given in ascending order and comprise the indices of the knots which give the first and last points of the curve. Use two consecutive values from the table as arguments of the global function SplitBSplineCurve (provided by the package GeomConvert) to split the curve. Exceptions Standard_DimensionError if the array SplitValues was not created with the following bounds: - 1, and - the number of split points computed in this framework (as given by the function NbSplits).
        """
    def __init__(self,BasisCurve : OCP.Geom.Geom_BSplineCurve,ContinuityRange : int) -> None: ...
    pass
class GeomConvert_BSplineCurveToBezierCurve():
    """
    An algorithm to convert a BSpline curve into a series of adjacent Bezier curves. A BSplineCurveToBezierCurve object provides a framework for: - defining the BSpline curve to be converted - implementing the construction algorithm, and - consulting the results. References : Generating the Bezier points of B-spline curves and surfaces (Wolfgang Bohm) CAD volume 13 number 6 november 1981
    """
    def Arc(self,Index : int) -> OCP.Geom.Geom_BezierCurve: 
        """
        Constructs and returns the Bezier curve of index Index to the table of adjacent Bezier arcs computed by this algorithm. This Bezier curve has the same orientation as the BSpline curve analyzed in this framework. Exceptions Standard_OutOfRange if Index is less than 1 or greater than the number of adjacent Bezier arcs computed by this algorithm.
        """
    def Arcs(self,Curves : OCP.TColGeom.TColGeom_Array1OfBezierCurve) -> None: 
        """
        Constructs all the Bezier curves whose data is computed by this algorithm and loads these curves into the Curves table. The Bezier curves have the same orientation as the BSpline curve analyzed in this framework. Exceptions Standard_DimensionError if the Curves array was not created with the following bounds: - 1 , and - the number of adjacent Bezier arcs computed by this algorithm (as given by the function NbArcs).
        """
    def Knots(self,TKnots : OCP.TColStd.TColStd_Array1OfReal) -> None: 
        """
        This methode returns the bspline's knots associated to the converted arcs Raised if the length of Curves is not equal to NbArcs + 1.
        """
    def NbArcs(self) -> int: 
        """
        Returns the number of BezierCurve arcs. If at the creation time you have decomposed the basis curve between the parametric values UFirst, ULast the number of BezierCurve arcs depends on the number of knots included inside the interval [UFirst, ULast]. If you have decomposed the whole basis B-spline curve the number of BezierCurve arcs NbArcs is equal to the number of knots less one.
        """
    @overload
    def __init__(self,BasisCurve : OCP.Geom.Geom_BSplineCurve) -> None: ...
    @overload
    def __init__(self,BasisCurve : OCP.Geom.Geom_BSplineCurve,U1 : float,U2 : float,ParametricTolerance : float) -> None: ...
    pass
class GeomConvert_BSplineSurfaceKnotSplitting():
    """
    An algorithm to determine isoparametric curves along which a BSpline surface should be split in order to obtain patches of the same continuity. The continuity order is given at the construction time. It is possible to compute the surface patches corresponding to the splitting with the method of package SplitBSplineSurface. For a B-spline surface the discontinuities are localised at the knot values. Between two knots values the B-spline is infinitely continuously differentiable. For each parametric direction at a knot of range index the continuity in this direction is equal to : Degree - Mult (Index) where Degree is the degree of the basis B-spline functions and Mult the multiplicity of the knot of range Index in the given direction. If for your computation you need to have B-spline surface with a minima of continuity it can be interesting to know between which knot values, a B-spline patch, has a continuity of given order. This algorithm computes the indexes of the knots where you should split the surface, to obtain patches with a constant continuity given at the construction time. If you just want to compute the local derivatives on the surface you don't need to create the BSpline patches, you can use the functions LocalD1, LocalD2, LocalD3, LocalDN of the class BSplineSurface from package Geom.
    """
    def NbUSplits(self) -> int: 
        """
        Returns the number of u-isoparametric curves along which the analysed BSpline surface should be split in order to obtain patches with the continuity required by this framework. The parameters which define these curves are knot values in the corresponding parametric direction. Note that the four curves which bound the surface are counted among these splitting curves.
        """
    def NbVSplits(self) -> int: 
        """
        Returns the number of v-isoparametric curves along which the analysed BSpline surface should be split in order to obtain patches with the continuity required by this framework. The parameters which define these curves are knot values in the corresponding parametric direction. Note that the four curves which bound the surface are counted among these splitting curves.
        """
    def Splitting(self,USplit : OCP.TColStd.TColStd_Array1OfInteger,VSplit : OCP.TColStd.TColStd_Array1OfInteger) -> None: 
        """
        Loads the USplit and VSplit tables with the split knots values computed in this framework. Each value in these tables is an index in the knots table corresponding to the u or v parametric direction of the BSpline surface analysed by this algorithm. The USplit and VSplit values are given in ascending order and comprise the indices of the knots which give the first and last isoparametric curves of the surface in the corresponding parametric direction. Use two consecutive values from the USplit table and two consecutive values from the VSplit table as arguments of the global function SplitBSplineSurface (provided by the package GeomConvert) to split the surface. Exceptions Standard_DimensionError if: - the array USplit was not created with the following bounds: - 1 , and - the number of split knots in the u parametric direction computed in this framework (as given by the function NbUSplits); or - the array VSplit was not created with the following bounds: - 1 , and - the number of split knots in the v parametric direction computed in this framework (as given by the function NbVSplits).
        """
    def USplitValue(self,UIndex : int) -> int: 
        """
        Returns the split knot of index UIndex to the split knots table for the u parametric direction computed in this framework. The returned value is an index in the knots table relative to the u parametric direction of the BSpline surface analysed by this algorithm. Note: If UIndex is equal to 1, or to the number of split knots for the u parametric direction computed in this framework, the corresponding knot gives the parameter of one of the bounding curves of the surface. Exceptions Standard_RangeError if UIndex is less than 1 or greater than the number of split knots for the u parametric direction computed in this framework.
        """
    def VSplitValue(self,VIndex : int) -> int: 
        """
        Returns the split knot of index VIndex to the split knots table for the v parametric direction computed in this framework. The returned value is an index in the knots table relative to the v parametric direction of the BSpline surface analysed by this algorithm. Note: If UIndex is equal to 1, or to the number of split knots for the v parametric direction computed in this framework, the corresponding knot gives the parameter of one of the bounding curves of the surface. Exceptions Standard_RangeError if VIndex is less than 1 or greater than the number of split knots for the v parametric direction computed in this framework.
        """
    def __init__(self,BasisSurface : OCP.Geom.Geom_BSplineSurface,UContinuityRange : int,VContinuityRange : int) -> None: ...
    pass
class GeomConvert_BSplineSurfaceToBezierSurface():
    """
    This algorithm converts a B-spline surface into several Bezier surfaces. It uses an algorithm of knot insertion. A BSplineSurfaceToBezierSurface object provides a framework for: - defining the BSpline surface to be converted, - implementing the construction algorithm, and - consulting the results. References : Generating the Bezier points of B-spline curves and surfaces (Wolfgang Bohm) CAD volume 13 number 6 november 1981
    """
    def NbUPatches(self) -> int: 
        """
        Returns the number of Bezier surfaces in the U direction. If at the creation time you have decomposed the basis Surface between the parametric values UFirst, ULast the number of Bezier surfaces in the U direction depends on the number of knots included inside the interval [UFirst, ULast]. If you have decomposed the whole basis B-spline surface the number of Bezier surfaces NbUPatches is equal to the number of UKnots less one.
        """
    def NbVPatches(self) -> int: 
        """
        Returns the number of Bezier surfaces in the V direction. If at the creation time you have decomposed the basis surface between the parametric values VFirst, VLast the number of Bezier surfaces in the V direction depends on the number of knots included inside the interval [VFirst, VLast]. If you have decomposed the whole basis B-spline surface the number of Bezier surfaces NbVPatches is equal to the number of VKnots less one.
        """
    def Patch(self,UIndex : int,VIndex : int) -> OCP.Geom.Geom_BezierSurface: 
        """
        Constructs and returns the Bezier surface of indices (UIndex, VIndex) to the patch grid computed on the BSpline surface analyzed by this algorithm. This Bezier surface has the same orientation as the BSpline surface analyzed in this framework. UIndex is an index common to a row in the patch grid. A row in the grid corresponds to a series of adjacent patches, all limited by the same two u-isoparametric curves of the surface. VIndex is an index common to a column in the patch grid. A column in the grid corresponds to a series of adjacent patches, all limited by the same two v-isoparametric curves of the surface. Exceptions Standard_OutOfRange if: - UIndex is less than 1 or greater than the number of rows in the patch grid computed on the BSpline surface analyzed by this algorithm (as returned by the function NbUPatches); or if - VIndex is less than 1 or greater than the number of columns in the patch grid computed on the BSpline surface analyzed by this algorithm (as returned by the function NbVPatches).
        """
    def Patches(self,Surfaces : OCP.TColGeom.TColGeom_Array2OfBezierSurface) -> None: 
        """
        Constructs all the Bezier surfaces whose data is computed by this algorithm, and loads them into the Surfaces table. These Bezier surfaces have the same orientation as the BSpline surface analyzed in this framework. The Surfaces array is organised in the same way as the patch grid computed on the BSpline surface analyzed by this algorithm. A row in the array corresponds to a series of adjacent patches, all limited by the same two u-isoparametric curves of the surface. A column in the array corresponds to a series of adjacent patches, all limited by the same two v-isoparametric curves of the surface. Exceptions Standard_DimensionError if the Surfaces array was not created with the following bounds: - 1, and the number of adjacent patch series in the u parametric direction of the patch grid computed on the BSpline surface, analyzed by this algorithm (as given by the function NbUPatches) as row bounds, - 1, and the number of adjacent patch series in the v parametric direction of the patch grid computed on the BSpline surface, analyzed by this algorithm (as given by the function NbVPatches) as column bounds.
        """
    def UKnots(self,TKnots : OCP.TColStd.TColStd_Array1OfReal) -> None: 
        """
        This methode returns the bspline's u-knots associated to the converted Patches Raised if the length of Curves is not equal to NbUPatches + 1.
        """
    def VKnots(self,TKnots : OCP.TColStd.TColStd_Array1OfReal) -> None: 
        """
        This methode returns the bspline's v-knots associated to the converted Patches Raised if the length of Curves is not equal to NbVPatches + 1.
        """
    @overload
    def __init__(self,BasisSurface : OCP.Geom.Geom_BSplineSurface) -> None: ...
    @overload
    def __init__(self,BasisSurface : OCP.Geom.Geom_BSplineSurface,U1 : float,U2 : float,V1 : float,V2 : float,ParametricTolerance : float) -> None: ...
    pass
class GeomConvert_CompBezierSurfacesToBSplineSurface():
    """
    An algorithm to convert a grid of adjacent non-rational Bezier surfaces (with continuity CM) into a BSpline surface (with continuity CM). A CompBezierSurfacesToBSplineSurface object provides a framework for: - defining the grid of adjacent Bezier surfaces which is to be converted into a BSpline surface, - implementing the computation algorithm, and - consulting the results. Warning Do not attempt to convert rational Bezier surfaces using such an algorithm. Input is array of Bezier patch 1 2 3 4 -> VIndex [1, NbVPatches] -> VDirection ----------------------- 1 | | | | | ----------------------- 2 | | | | | ----------------------- 3 | | | | | ----------------------- UIndex [1, NbUPatches] Udirection
    """
    def IsDone(self) -> bool: 
        """
        Returns true if the conversion was successful. Unless an exception was raised at the time of construction, the conversion of the Bezier surface grid assigned to this algorithm is always carried out. IsDone returns false if the constraints defined at the time of construction cannot be respected. This occurs when there is an incompatibility between a required degree of continuity on the BSpline surface, and the maximum tolerance accepted for local deformations of the surface. In such a case the computed data does not satisfy all the initial constraints.
        """
    def NbUKnots(self) -> int: 
        """
        Returns the number of knots in the U direction of the BSpline surface whose data is computed in this framework.

        Returns the number of knots in the U direction of the BSpline surface whose data is computed in this framework.
        """
    def NbUPoles(self) -> int: 
        """
        Returns number of poles in the U direction of the BSpline surface whose data is computed in this framework.

        Returns number of poles in the U direction of the BSpline surface whose data is computed in this framework.
        """
    def NbVKnots(self) -> int: 
        """
        Returns the number of knots in the V direction of the BSpline surface whose data is computed in this framework.

        Returns the number of knots in the V direction of the BSpline surface whose data is computed in this framework.
        """
    def NbVPoles(self) -> int: 
        """
        Returns the number of poles in the V direction of the BSpline surface whose data is computed in this framework.

        Returns the number of poles in the V direction of the BSpline surface whose data is computed in this framework.
        """
    def Poles(self) -> OCP.TColgp.TColgp_HArray2OfPnt: 
        """
        Returns the table of poles of the BSpline surface whose data is computed in this framework.

        Returns the table of poles of the BSpline surface whose data is computed in this framework.
        """
    def UDegree(self) -> int: 
        """
        Returns the degree for the u parametric direction of the BSpline surface whose data is computed in this framework.

        Returns the degree for the u parametric direction of the BSpline surface whose data is computed in this framework.
        """
    def UKnots(self) -> OCP.TColStd.TColStd_HArray1OfReal: 
        """
        Returns the knots table for the u parametric direction of the BSpline surface whose data is computed in this framework.

        Returns the knots table for the u parametric direction of the BSpline surface whose data is computed in this framework.
        """
    def UMultiplicities(self) -> OCP.TColStd.TColStd_HArray1OfInteger: 
        """
        Returns the multiplicities table for the u parametric direction of the knots of the BSpline surface whose data is computed in this framework.

        Returns the multiplicities table for the u parametric direction of the knots of the BSpline surface whose data is computed in this framework.
        """
    def VDegree(self) -> int: 
        """
        Returns the degree for the v parametric direction of the BSpline surface whose data is computed in this framework.

        Returns the degree for the v parametric direction of the BSpline surface whose data is computed in this framework.
        """
    def VKnots(self) -> OCP.TColStd.TColStd_HArray1OfReal: 
        """
        Returns the knots table for the v parametric direction of the BSpline surface whose data is computed in this framework.

        Returns the knots table for the v parametric direction of the BSpline surface whose data is computed in this framework.
        """
    def VMultiplicities(self) -> OCP.TColStd.TColStd_HArray1OfInteger: 
        """
        -- Returns the multiplicities table for the v parametric direction of the knots of the BSpline surface whose data is computed in this framework.

        -- Returns the multiplicities table for the v parametric direction of the knots of the BSpline surface whose data is computed in this framework.
        """
    @overload
    def __init__(self,Beziers : OCP.TColGeom.TColGeom_Array2OfBezierSurface) -> None: ...
    @overload
    def __init__(self,Beziers : OCP.TColGeom.TColGeom_Array2OfBezierSurface,Tolerance : float,RemoveKnots : bool=True) -> None: ...
    @overload
    def __init__(self,Beziers : OCP.TColGeom.TColGeom_Array2OfBezierSurface,UKnots : OCP.TColStd.TColStd_Array1OfReal,VKnots : OCP.TColStd.TColStd_Array1OfReal,UContinuity : OCP.GeomAbs.GeomAbs_Shape=GeomAbs_Shape.GeomAbs_C0,VContinuity : OCP.GeomAbs.GeomAbs_Shape=GeomAbs_Shape.GeomAbs_C0,Tolerance : float=0.0001) -> None: ...
    pass
class GeomConvert_CompCurveToBSplineCurve():
    """
    Algorithm converts and concat several curve in an BSplineCurve
    """
    def Add(self,NewCurve : OCP.Geom.Geom_BoundedCurve,Tolerance : float,After : bool=False,WithRatio : bool=True,MinM : int=0) -> bool: 
        """
        Append a curve in the BSpline Return False if the curve is not G0 with the BSplineCurve. Tolerance is used to check continuity and decrease Multiplicity at the common Knot until MinM if MinM = 0, the common Knot can be removed
        """
    def BSplineCurve(self) -> OCP.Geom.Geom_BSplineCurve: ...
    def Clear(self) -> None: 
        """
        Clear a result curve
        """
    @overload
    def __init__(self,Parameterisation : OCP.Convert.Convert_ParameterisationType=Convert_ParameterisationType.Convert_TgtThetaOver2) -> None: ...
    @overload
    def __init__(self,BasisCurve : OCP.Geom.Geom_BoundedCurve,Parameterisation : OCP.Convert.Convert_ParameterisationType=Convert_ParameterisationType.Convert_TgtThetaOver2) -> None: ...
    pass
class GeomConvert_ConvType():
    """
    Members:

      GeomConvert_Target

      GeomConvert_Simplest

      GeomConvert_MinGap
    """
    def __eq__(self,other : object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __init__(self,value : int) -> None: ...
    def __int__(self) -> int: ...
    def __ne__(self,other : object) -> bool: ...
    def __repr__(self) -> str: ...
    def __setstate__(self,state : int) -> None: ...
    def __str__(self) -> str: ...
    @property
    def name(self) -> None:
        """
        :type: None
        """
    @property
    def value(self) -> int:
        """
        :type: int
        """
    GeomConvert_MinGap: OCP.GeomConvert.GeomConvert_ConvType # value = <GeomConvert_ConvType.GeomConvert_MinGap: 2>
    GeomConvert_Simplest: OCP.GeomConvert.GeomConvert_ConvType # value = <GeomConvert_ConvType.GeomConvert_Simplest: 1>
    GeomConvert_Target: OCP.GeomConvert.GeomConvert_ConvType # value = <GeomConvert_ConvType.GeomConvert_Target: 0>
    __entries: dict # value = {'GeomConvert_Target': (<GeomConvert_ConvType.GeomConvert_Target: 0>, None), 'GeomConvert_Simplest': (<GeomConvert_ConvType.GeomConvert_Simplest: 1>, None), 'GeomConvert_MinGap': (<GeomConvert_ConvType.GeomConvert_MinGap: 2>, None)}
    __members__: dict # value = {'GeomConvert_Target': <GeomConvert_ConvType.GeomConvert_Target: 0>, 'GeomConvert_Simplest': <GeomConvert_ConvType.GeomConvert_Simplest: 1>, 'GeomConvert_MinGap': <GeomConvert_ConvType.GeomConvert_MinGap: 2>}
    pass
class GeomConvert_CurveToAnaCurve():
    @staticmethod
    def ComputeCircle_s(curve : OCP.Geom.Geom_Curve,tolerance : float,c1 : float,c2 : float,cf : float,cl : float,Deviation : float) -> OCP.Geom.Geom_Curve: 
        """
        Tries to convert the given curve to circle with given tolerance. Returns NULL curve if conversion is not possible.
        """
    @staticmethod
    def ComputeCurve_s(curve : OCP.Geom.Geom_Curve,tolerance : float,c1 : float,c2 : float,cf : float,cl : float,theGap : float,theCurvType : GeomConvert_ConvType=GeomConvert_ConvType.GeomConvert_MinGap,theTarget : OCP.GeomAbs.GeomAbs_CurveType=GeomAbs_CurveType.GeomAbs_Line) -> OCP.Geom.Geom_Curve: ...
    @staticmethod
    def ComputeEllipse_s(curve : OCP.Geom.Geom_Curve,tolerance : float,c1 : float,c2 : float,cf : float,cl : float,Deviation : float) -> OCP.Geom.Geom_Curve: 
        """
        Tries to convert the given curve to ellipse with given tolerance. Returns NULL curve if conversion is not possible.
        """
    @staticmethod
    def ComputeLine_s(curve : OCP.Geom.Geom_Curve,tolerance : float,c1 : float,c2 : float,cf : float,cl : float,Deviation : float) -> OCP.Geom.Geom_Line: 
        """
        Tries to convert the given curve to line with given tolerance. Returns NULL curve if conversion is not possible.
        """
    def ConvertToAnalytical(self,theTol : float,theResultCurve : OCP.Geom.Geom_Curve,F : float,L : float,newF : float,newL : float) -> bool: 
        """
        Converts me to analytical if possible with given tolerance. The new first and last parameters are returned to newF, newL
        """
    def Gap(self) -> float: 
        """
        Returns maximal deviation of converted surface from the original one computed by last call to ConvertToAnalytical
        """
    @staticmethod
    def GetCircle_s(Circ : OCP.gp.gp_Circ,P0 : OCP.gp.gp_Pnt,P1 : OCP.gp.gp_Pnt,P2 : OCP.gp.gp_Pnt) -> bool: 
        """
        Creates circle on points. Returns true if OK.
        """
    def GetConvType(self) -> GeomConvert_ConvType: 
        """
        Returns conversion type
        """
    @staticmethod
    def GetLine_s(P1 : OCP.gp.gp_Pnt,P2 : OCP.gp.gp_Pnt,cf : float,cl : float) -> OCP.gp.gp_Lin: 
        """
        Creates line on two points. Resulting parameters returned
        """
    def GetTarget(self) -> OCP.GeomAbs.GeomAbs_CurveType: 
        """
        Returns target curve type
        """
    def Init(self,C : OCP.Geom.Geom_Curve) -> None: ...
    @staticmethod
    def IsLinear_s(aPoints : OCP.TColgp.TColgp_Array1OfPnt,tolerance : float,Deviation : float) -> bool: 
        """
        Returns true if the set of points is linear with given tolerance
        """
    def SetConvType(self,theConvType : GeomConvert_ConvType) -> None: 
        """
        Sets type of conversion
        """
    def SetTarget(self,theTarget : OCP.GeomAbs.GeomAbs_CurveType) -> None: 
        """
        Sets target curve type
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,C : OCP.Geom.Geom_Curve) -> None: ...
    pass
class GeomConvert_FuncConeLSDist(OCP.math.math_MultipleVarFunction):
    """
    Function for search of Cone canonic parameters: coordinates of center local coordinate system, direction of axis, radius and semi-angle from set of points by least square method.
    """
    def GetStateNumber(self) -> int: 
        """
        return the state of the function corresponding to the latestt call of any methods associated to the function. This function is called by each of the algorithms described later which define the function Integer Algorithm::StateNumber(). The algorithm has the responsibility to call this function when it has found a solution (i.e. a root or a minimum) and has to maintain the association between the solution found and this StateNumber. Byu default, this method returns 0 (which means for the algorithm: no state has been saved). It is the responsibility of the programmer to decide if he needs to save the current state of the function and to return an Integer that allows retrieval of the state.
        """
    def NbVariables(self) -> int: 
        """
        Number of variables.
        """
    def SetDir(self,theDir : OCP.gp.gp_Dir) -> None: ...
    def SetPoints(self,thePoints : OCP.TColgp.TColgp_HArray1OfXYZ) -> None: ...
    def Value(self,X : Any,F : float) -> bool: 
        """
        Value.
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,thePoints : OCP.TColgp.TColgp_HArray1OfXYZ,theDir : OCP.gp.gp_Dir) -> None: ...
    pass
class GeomConvert_FuncCylinderLSDist(OCP.math.math_MultipleVarFunctionWithGradient, OCP.math.math_MultipleVarFunction):
    """
    Function for search of cylinder canonic parameters: coordinates of center local coordinate system, direction of axis and radius from set of points by least square method.
    """
    def GetStateNumber(self) -> int: 
        """
        return the state of the function corresponding to the latestt call of any methods associated to the function. This function is called by each of the algorithms described later which define the function Integer Algorithm::StateNumber(). The algorithm has the responsibility to call this function when it has found a solution (i.e. a root or a minimum) and has to maintain the association between the solution found and this StateNumber. Byu default, this method returns 0 (which means for the algorithm: no state has been saved). It is the responsibility of the programmer to decide if he needs to save the current state of the function and to return an Integer that allows retrieval of the state.
        """
    def Gradient(self,X : Any,G : Any) -> bool: 
        """
        Gradient.
        """
    def NbVariables(self) -> int: 
        """
        Number of variables.
        """
    def SetDir(self,theDir : OCP.gp.gp_Dir) -> None: ...
    def SetPoints(self,thePoints : OCP.TColgp.TColgp_HArray1OfXYZ) -> None: ...
    def Value(self,X : Any,F : float) -> bool: 
        """
        Value.
        """
    def Values(self,X : Any,F : float,G : Any) -> bool: 
        """
        Value and gradient.
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,thePoints : OCP.TColgp.TColgp_HArray1OfXYZ,theDir : OCP.gp.gp_Dir) -> None: ...
    pass
class GeomConvert_FuncSphereLSDist(OCP.math.math_MultipleVarFunctionWithGradient, OCP.math.math_MultipleVarFunction):
    """
    Function for search of sphere canonic parameters: coordinates of center and radius from set of moints by least square method. //! The class inherits math_MultipleVarFunctionWithGradient and thus is intended for use in math_BFGS algorithm.
    """
    def GetStateNumber(self) -> int: 
        """
        return the state of the function corresponding to the latestt call of any methods associated to the function. This function is called by each of the algorithms described later which define the function Integer Algorithm::StateNumber(). The algorithm has the responsibility to call this function when it has found a solution (i.e. a root or a minimum) and has to maintain the association between the solution found and this StateNumber. Byu default, this method returns 0 (which means for the algorithm: no state has been saved). It is the responsibility of the programmer to decide if he needs to save the current state of the function and to return an Integer that allows retrieval of the state.
        """
    def Gradient(self,X : Any,G : Any) -> bool: 
        """
        Gradient.
        """
    def NbVariables(self) -> int: 
        """
        Number of variables.
        """
    def SetPoints(self,thePoints : OCP.TColgp.TColgp_HArray1OfXYZ) -> None: ...
    def Value(self,X : Any,F : float) -> bool: 
        """
        Value.
        """
    def Values(self,X : Any,F : float,G : Any) -> bool: 
        """
        Value and gradient.
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,thePoints : OCP.TColgp.TColgp_HArray1OfXYZ) -> None: ...
    pass
class GeomConvert_SurfToAnaSurf():
    """
    Converts a surface to the analytical form with given precision. Conversion is done only the surface is bspline of bezier and this can be approximated by some analytical surface with that precision.
    """
    @overload
    def ConvertToAnalytical(self,InitialToler : float) -> OCP.Geom.Geom_Surface: 
        """
        Tries to convert the Surface to an Analytic form Returns the result In case of failure, returns a Null Handle
        """
    @overload
    def ConvertToAnalytical(self,InitialToler : float,Umin : float,Umax : float,Vmin : float,Vmax : float) -> OCP.Geom.Geom_Surface: ...
    def Gap(self) -> float: 
        """
        Returns maximal deviation of converted surface from the original one computed by last call to ConvertToAnalytical
        """
    def Init(self,S : OCP.Geom.Geom_Surface) -> None: ...
    @staticmethod
    def IsCanonical_s(S : OCP.Geom.Geom_Surface) -> bool: 
        """
        Returns true, if surface is canonical
        """
    @staticmethod
    def IsSame_s(S1 : OCP.Geom.Geom_Surface,S2 : OCP.Geom.Geom_Surface,tol : float) -> bool: 
        """
        Returns true if surfaces is same with the given tolerance
        """
    def SetConvType(self,theConvType : GeomConvert_ConvType=GeomConvert_ConvType.GeomConvert_Simplest) -> None: ...
    def SetTarget(self,theSurfType : OCP.GeomAbs.GeomAbs_SurfaceType=GeomAbs_SurfaceType.GeomAbs_Plane) -> None: ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,S : OCP.Geom.Geom_Surface) -> None: ...
    pass
class GeomConvert_Units():
    """
    Class contains conversion methods for 2d geom objects
    """
    @staticmethod
    def DegreeToRadian_s(theCurve : OCP.Geom2d.Geom2d_Curve,theSurface : OCP.Geom.Geom_Surface,theLengthFactor : float,theFactorRadianDegree : float) -> OCP.Geom2d.Geom2d_Curve: 
        """
        Convert 2d curve for change angle unit from degree to radian
        """
    @staticmethod
    def MirrorPCurve_s(theCurve : OCP.Geom2d.Geom2d_Curve) -> OCP.Geom2d.Geom2d_Curve: 
        """
        return 2d curve as 'mirror' for given
        """
    @staticmethod
    def RadianToDegree_s(theCurve : OCP.Geom2d.Geom2d_Curve,theSurface : OCP.Geom.Geom_Surface,theLengthFactor : float,theFactorRadianDegree : float) -> OCP.Geom2d.Geom2d_Curve: 
        """
        Convert 2d curve for change angle unit from radian to degree
        """
    def __init__(self) -> None: ...
    pass
GeomConvert_MinGap: OCP.GeomConvert.GeomConvert_ConvType # value = <GeomConvert_ConvType.GeomConvert_MinGap: 2>
GeomConvert_Simplest: OCP.GeomConvert.GeomConvert_ConvType # value = <GeomConvert_ConvType.GeomConvert_Simplest: 1>
GeomConvert_Target: OCP.GeomConvert.GeomConvert_ConvType # value = <GeomConvert_ConvType.GeomConvert_Target: 0>
